@@ -13,5 +13,6 @@ var namespacezypp_1_1env =
     [ "ZYPP_MEDIA_CURL_DEBUG", "namespacezypp_1_1env.html#a44ac5e5995923d4d078e0cd036ccb357", null ],
     [ "ZYPP_MEDIA_CURL_IPRESOLVE", "namespacezypp_1_1env.html#a4afff5bd7986ed5db57c297e7aad1702", null ],
     [ "ZYPP_METALINK_DEBUG", "namespacezypp_1_1env.html#a6d32234b50d31d7cfd3bdefc6f2d0753", null ],
-    [ "inYAST", "namespacezypp_1_1env.html#a516fcc088e11b622eb7079018fea9886", null ]
+    [ "inYAST", "namespacezypp_1_1env.html#a516fcc088e11b622eb7079018fea9886", null ],
+    [ "PX_DEBUG", "namespacezypp_1_1env.html#a3b7ab8ea2ff31f170f448f8bf944fe6c", null ]
 ];
\ No newline at end of file
