@@ -385,7 +385,8 @@ var namespacezyppng =
     [ "UserRequest", "classzyppng_1_1UserRequest.html", "classzyppng_1_1UserRequest" ],
     [ "Wakeup", "classzyppng_1_1Wakeup.html", "classzyppng_1_1Wakeup" ],
     [ "WorkerCaps", "classzyppng_1_1WorkerCaps.html", "classzyppng_1_1WorkerCaps" ],
-    [ "ZckHelper", "classzyppng_1_1ZckHelper.html", "classzyppng_1_1ZckHelper" ],
+    [ "ZckError", "classzyppng_1_1ZckError.html", "classzyppng_1_1ZckError" ],
+    [ "ZckLoader", "classzyppng_1_1ZckLoader.html", "classzyppng_1_1ZckLoader" ],
     [ "KeyRing", "namespacezyppng.html#a2c0f79ed9e5fb75b7e04c0ac651f06dd", null ],
     [ "KeyRingRef", "namespacezyppng.html#a5871ccc48bf67277d35c18493fbada8f", null ],
     [ "AsyncLazyMediaHandle", "namespacezyppng.html#a73c4cefa9f437858fd693a0cf497b9d5", null ],
