@@ -145,14 +145,15 @@ var NAVTREEINDEX1 =
 "MediaSource_8cc_source.html":[5,0,0,1,35],
 "MediaSource_8h.html":[5,0,0,1,36],
 "MediaSource_8h_source.html":[5,0,0,1,36],
-"MediaUrl_8cc.html":[5,0,0,1,37],
-"MediaUrl_8cc_source.html":[5,0,0,1,37],
-"MediaUrl_8h.html":[5,0,0,1,38],
-"MediaUrl_8h_source.html":[5,0,0,1,38],
-"MediaUserAuth_8h.html":[5,0,0,1,39],
-"MediaUserAuth_8h_source.html":[5,0,0,1,39],
-"MetaLinkParser_8h.html":[5,0,0,1,40],
-"MetaLinkParser_8h_source.html":[5,0,0,1,40],
+"MediaUserAuth_8h.html":[5,0,0,1,37],
+"MediaUserAuth_8h_source.html":[5,0,0,1,37],
+"MetaLinkParser_8h.html":[5,0,0,1,38],
+"MetaLinkParser_8h_source.html":[5,0,0,1,38],
+"MirroredOrigin_8cc.html":[5,0,1,22],
+"MirroredOrigin_8cc.html#ad11ca1dc9757eafa29e9de2259388ff4":[5,0,1,22,3],
+"MirroredOrigin_8cc_source.html":[5,0,1,22],
+"MirroredOrigin_8h.html":[5,0,1,23],
+"MirroredOrigin_8h_source.html":[5,0,1,23],
 "Misc_8h.html":[5,0,0,84],
 "Misc_8h_source.html":[5,0,0,84],
 "Modalias_8cc.html":[5,0,0,9,0,0],
@@ -161,8 +162,8 @@ var NAVTREEINDEX1 =
 "Modalias_8cc_source.html":[5,0,0,9,0,0],
 "Modalias_8h.html":[5,0,0,9,0,1],
 "Modalias_8h_source.html":[5,0,0,9,0,1],
-"Mount_8h.html":[5,0,0,1,41],
-"Mount_8h_source.html":[5,0,0,1,41],
+"Mount_8h.html":[5,0,0,1,39],
+"Mount_8h_source.html":[5,0,0,1,39],
 "NamedValue_8h.html":[5,0,0,0,34],
 "NamedValue_8h_source.html":[5,0,0,0,34],
 "Node_8cc.html":[5,0,0,4,1,2],
@@ -222,8 +223,8 @@ var NAVTREEINDEX1 =
 "Patch_8cc_source.html":[5,0,0,89],
 "Patch_8h.html":[5,0,0,90],
 "Patch_8h_source.html":[5,0,0,90],
-"Pathname_8cc.html":[5,0,1,24],
-"Pathname_8cc_source.html":[5,0,1,24],
+"Pathname_8cc.html":[5,0,1,26],
+"Pathname_8cc_source.html":[5,0,1,26],
 "Pattern_8cc.html":[5,0,0,94],
 "Pattern_8cc_source.html":[5,0,0,94],
 "Pattern_8h.html":[5,0,0,95],
@@ -248,6 +249,5 @@ var NAVTREEINDEX1 =
 "PluginRepoverification_8h_source.html":[5,0,0,6,12],
 "PluginScriptException_8cc.html":[5,0,0,100],
 "PluginScriptException_8cc_source.html":[5,0,0,100],
-"PluginScriptException_8h.html":[5,0,0,101],
-"PluginScriptException_8h.html#a21ab8f4173229c8183ba697ec92cae2a":[5,0,0,101,1]
+"PluginScriptException_8h.html":[5,0,0,101]
 };
