@@ -1,5 +1,56 @@
 var NAVTREEINDEX100 =
 {
+"namespacezypp_1_1iostr.html#a714b23c365ad1e7891351ecaf97cf7b6":[3,0,10,20,1],
+"namespacezypp_1_1iostr.html#a9342f8cee672775c5308cb3fd9d7eb4c":[3,0,10,20,3],
+"namespacezypp_1_1iostr.html#aa922dd9b33377332dd6c7dc3060832a5":[3,0,10,20,6],
+"namespacezypp_1_1iostr.html#ac3ed81384689d781c7e5736eb2cc8a8c":[3,0,10,20,8],
+"namespacezypp_1_1iostr.html#acae8a150665dc5989f8346ac2bd4dca3":[3,0,10,20,13],
+"namespacezypp_1_1iostr.html#ad84b3964177cbbf9fee307c892ae1fc0":[3,0,10,20,11],
+"namespacezypp_1_1json.html":[3,0,10,21],
+"namespacezypp_1_1json.html#a02fbe70eb559a6983b92e16c0a021cf3":[3,0,10,21,13],
+"namespacezypp_1_1json.html#a0691f8eacd7dc8d6cecc315bce149193":[3,0,10,21,12],
+"namespacezypp_1_1json.html#a4441476727824acd486eef6058cc70df":[3,0,10,21,15],
+"namespacezypp_1_1json.html#a842e76ce474a7abcd5b012fb4c5a1cba":[3,0,10,21,11],
+"namespacezypp_1_1json.html#ab55857235d962051c9e004441a259972":[3,0,10,21,16],
+"namespacezypp_1_1json.html#ad8f19c88ae368ec029ffe959a647606c":[3,0,10,21,14],
+"namespacezypp_1_1json.html#ae8653c4433fdaddbcb0e65374df3ede3":[3,0,10,21,17],
+"namespacezypp_1_1json.html#af68e596bf9d30f8458bd94a3f662d88d":[3,0,10,21,27],
+"namespacezypp_1_1json_1_1detail.html":[3,0,10,21,0],
+"namespacezypp_1_1json_1_1detail.html#a4d63e93952132de3b03744317a6e5408":[3,0,10,21,0,0],
+"namespacezypp_1_1keyring.html":[3,0,10,22],
+"namespacezypp_1_1keyring.html#abc2d9173d1613fd82022b76d6f7df7e6":[3,0,10,22,1],
+"namespacezypp_1_1kvmap.html":[3,0,10,23],
+"namespacezypp_1_1log.html":[3,0,10,24],
+"namespacezypp_1_1media.html":[3,0,10,25],
+"namespacezypp_1_1media.html#a08a1cdd89a2dc3e81655c90559997bcb":[3,0,10,25,89],
+"namespacezypp_1_1media.html#a13038cc28702080cd6c2016bbb0ab631":[3,0,10,25,81],
+"namespacezypp_1_1media.html#a147c1d7d582224cfe256373e35a16940":[3,0,10,25,110],
+"namespacezypp_1_1media.html#a15422d1f797c890670d657f1cd655349":[3,0,10,25,94],
+"namespacezypp_1_1media.html#a1650cc07e912327e0b4a3de64e46cae1":[3,0,10,25,97],
+"namespacezypp_1_1media.html#a1c72c0eaacf99a37ebed5a0775da22da":[3,0,10,25,91],
+"namespacezypp_1_1media.html#a253eea8c981a10cb3cf028e3fa9a3f90":[3,0,10,25,96],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59":[3,0,10,25,93],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a140b09043eab1d1ff4aeaf15d7b3933e":[3,0,10,25,93,4],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a1d221559ce780df327603d00e5c19794":[3,0,10,25,93,8],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a49396d3fd4df41fb3bd5b3d83e772bf7":[3,0,10,25,93,6],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a4f70f18367c79b474e96041a07967157":[3,0,10,25,93,17],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a6078771c79fa94bed124bb952110371b":[3,0,10,25,93,16],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a6423199a3e9580a3ef36d95a3d8610db":[3,0,10,25,93,0],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a64b98fd17e3bad00ad58aeb1d3b9a7b7":[3,0,10,25,93,14],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a7ee9bcd11265cab9ca4cb4d21b6593c7":[3,0,10,25,93,12],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a7f5485a0ef07bb4e6ef27fc9b06e11dd":[3,0,10,25,93,10],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a8a553e5c8e1329dd11d172f849c124a9":[3,0,10,25,93,5],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59a8ac8be2fb09c49a663a08ce6977a0365":[3,0,10,25,93,1],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59aa8df758af8c88624f2736eaf3a757d7d":[3,0,10,25,93,7],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59ab1a4612907e48e5d59d331968b638e7a":[3,0,10,25,93,15],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59ac3ab99b4b9491708b02dfaaaf65eeb20":[3,0,10,25,93,3],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59ac8ad6880d24bf844bb5e1f8ad02f97f7":[3,0,10,25,93,13],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59aef62f20f2eceafbcd7f12a1ace3d5e89":[3,0,10,25,93,9],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59af361d5d9c0eee9941492a61a14e34207":[3,0,10,25,93,11],
+"namespacezypp_1_1media.html#a290198b39b90deb48ce4c5f30b926f59afae90bc3907a3ab28a1c3556bca918e4":[3,0,10,25,93,2],
+"namespacezypp_1_1media.html#a2b602bde97e5ca2c3efe468957b130f0":[3,0,10,25,104],
+"namespacezypp_1_1media.html#a2e00dc0213ffd57140749581d1768e24":[3,0,10,25,101],
+"namespacezypp_1_1media.html#a37b761b9b1ffcfd28684588992f3a825":[3,0,10,25,92],
 "namespacezypp_1_1media.html#a37b761b9b1ffcfd28684588992f3a825a6adf97f83acf6453d4a6a4b1070f3754":[3,0,10,25,92,0],
 "namespacezypp_1_1media.html#a37b761b9b1ffcfd28684588992f3a825aa4f27de733f41d8de8c96ad59ea0c7f4":[3,0,10,25,92,2],
 "namespacezypp_1_1media.html#a37b761b9b1ffcfd28684588992f3a825aa8760d7c86915746134252e4a65751e5":[3,0,10,25,92,1],
@@ -198,56 +249,5 @@ var NAVTREEINDEX100 =
 "namespacezypp_1_1sat_1_1detail.html#a67e6184ac25348532496d86b81bcb4f1":[3,0,10,37,0,29],
 "namespacezypp_1_1sat_1_1detail.html#a706af4efab083d577ea47ebe278c9723":[3,0,10,37,0,24],
 "namespacezypp_1_1sat_1_1detail.html#a721585f102a332951b750f7a6e2a0a91":[3,0,10,37,0,45],
-"namespacezypp_1_1sat_1_1detail.html#a7a3025a734f4e8235c12bdc7ae15e634":[3,0,10,37,0,47],
-"namespacezypp_1_1sat_1_1detail.html#a7a58e18e5dfec551c94d4f297416c94d":[3,0,10,37,0,12],
-"namespacezypp_1_1sat_1_1detail.html#a7e9a3049ad4c7542ea1cd5cee91a5432":[3,0,10,37,0,41],
-"namespacezypp_1_1sat_1_1detail.html#a819ca1c99fe2774364a13b580146d9b1":[3,0,10,37,0,25],
-"namespacezypp_1_1sat_1_1detail.html#a86243ff14cd229d4a0f6a4a28b8fdbc8":[3,0,10,37,0,49],
-"namespacezypp_1_1sat_1_1detail.html#a8ad3b97a250fc77cf626d4e497f13a45":[3,0,10,37,0,38],
-"namespacezypp_1_1sat_1_1detail.html#a8ee2e846d5a2b96fd17fdecfadbe1e15":[3,0,10,37,0,16],
-"namespacezypp_1_1sat_1_1detail.html#a8fc1ab3191e8723821bdb6fe32429bb6":[3,0,10,37,0,11],
-"namespacezypp_1_1sat_1_1detail.html#a9d13f87f8705b331b9764ae332d044a7":[3,0,10,37,0,51],
-"namespacezypp_1_1sat_1_1detail.html#a9e87882a2a0b31e564b5082c157dd7b5":[3,0,10,37,0,48],
-"namespacezypp_1_1sat_1_1detail.html#aa856bd32b2e33c7e8f1632876d10275f":[3,0,10,37,0,13],
-"namespacezypp_1_1sat_1_1detail.html#aad87ca9042ae27e9c1df8c4c7055bd65":[3,0,10,37,0,14],
-"namespacezypp_1_1sat_1_1detail.html#ab3bcbefc0993770ee08778c8952939e4":[3,0,10,37,0,27],
-"namespacezypp_1_1sat_1_1detail.html#abb588f2f0dc4c2e69b2195739edf5348":[3,0,10,37,0,10],
-"namespacezypp_1_1sat_1_1detail.html#abdeb1d2e0ecd5faa76b4125221989c6b":[3,0,10,37,0,31],
-"namespacezypp_1_1sat_1_1detail.html#abf634892fe1f353283f2a4df20744b01":[3,0,10,37,0,20],
-"namespacezypp_1_1sat_1_1detail.html#ac9b8fee0aa7232cfb5f7ac07582f8031":[3,0,10,37,0,8],
-"namespacezypp_1_1sat_1_1detail.html#acd04159285e4987ba50a081a2a629f90":[3,0,10,37,0,7],
-"namespacezypp_1_1sat_1_1detail.html#ace504736bbfb0f51f519fa83f50ab21a":[3,0,10,37,0,33],
-"namespacezypp_1_1sat_1_1detail.html#add5394f3d75f54d95a8ec35263bc3dc9":[3,0,10,37,0,35],
-"namespacezypp_1_1sat_1_1detail.html#ae3a559660c2cd6e85ff7acf068131860":[3,0,10,37,0,52],
-"namespacezypp_1_1sat_1_1detail.html#ae84ecb8be3220e74a4294f14f55f093f":[3,0,10,37,0,15],
-"namespacezypp_1_1sat_1_1detail.html#ae857f66930a66bad558687f20365819c":[3,0,10,37,0,36],
-"namespacezypp_1_1sat_1_1detail.html#aecde2e5b4857212b855bb6f39006065f":[3,0,10,37,0,50],
-"namespacezypp_1_1sat_1_1detail.html#af1934d44a5e9d893d127a2f69d4886cb":[3,0,10,37,0,19],
-"namespacezypp_1_1sat_1_1detail.html#af84402c3ada06d046971325c799a63b0":[3,0,10,37,0,26],
-"namespacezypp_1_1sat_1_1detail.html#afb075fec8691c01828d39963986ca547":[3,0,10,37,0,32],
-"namespacezypp_1_1sat_1_1detail.html#afc2709df90d72dca5f2d240ee48cf61c":[3,0,10,37,0,22],
-"namespacezypp_1_1sat_1_1detail.html#aff049ffc36b71c034d98f88fcf889561":[3,0,10,37,0,34],
-"namespacezypp_1_1sat_1_1detail.html#affb76d498bc9384fb8fa5f223ea55623":[3,0,10,37,0,39],
-"namespacezypp_1_1sat_1_1solvitermixin__detail.html":[3,0,10,37,1],
-"namespacezypp_1_1sighandler.html":[3,0,10,38],
-"namespacezypp_1_1sighandler.html#aae3f5b8e54c21e0671059e3eee45e230":[3,0,10,38,1],
-"namespacezypp_1_1solver.html":[3,0,10,39],
-"namespacezypp_1_1solver_1_1detail.html":[3,0,10,39,0],
-"namespacezypp_1_1solver_1_1detail.html#a03b0e490b0dfa6676f33b463dc7b29a6":[3,0,10,39,0,38],
-"namespacezypp_1_1solver_1_1detail.html#a1526c80fa583bf5b785fb89fb7a7b6d2":[3,0,10,39,0,51],
-"namespacezypp_1_1solver_1_1detail.html#a232c2f7a8c0176fc0c62a26ad1272864":[3,0,10,39,0,35],
-"namespacezypp_1_1solver_1_1detail.html#a2aa0a3588f61fa4a0fb1b90ce5353521":[3,0,10,39,0,40],
-"namespacezypp_1_1solver_1_1detail.html#a2d0517433cfa1fcb00a0ba5491629510":[3,0,10,39,0,53],
-"namespacezypp_1_1solver_1_1detail.html#a392b5e9de7c55b804e21aa6fe6e00d08":[3,0,10,39,0,16],
-"namespacezypp_1_1solver_1_1detail.html#a4b1178ae387abe22d3e77542c61d832c":[3,0,10,39,0,36],
-"namespacezypp_1_1solver_1_1detail.html#a4bc6115e128b23b793d211ac4bdf54b2":[3,0,10,39,0,52],
-"namespacezypp_1_1solver_1_1detail.html#a505655a6dd7b0ebc6135fc62382d0126":[3,0,10,39,0,22],
-"namespacezypp_1_1solver_1_1detail.html#a5b3e3069dfb27237b2bd5339531abc56":[3,0,10,39,0,33],
-"namespacezypp_1_1solver_1_1detail.html#a6fc6aaedf13fb8abe6955b62c470302b":[3,0,10,39,0,32],
-"namespacezypp_1_1solver_1_1detail.html#a743ebde5babcee68e8a72c7894197371":[3,0,10,39,0,34],
-"namespacezypp_1_1solver_1_1detail.html#a82128d887a1d6822cf7eae317620f155":[3,0,10,39,0,24],
-"namespacezypp_1_1solver_1_1detail.html#a82a35c23d93cb141d74abccc881268f8":[3,0,10,39,0,29],
-"namespacezypp_1_1solver_1_1detail.html#a8341b35a42894d46c20bbc8207153ca3":[3,0,10,39,0,27],
-"namespacezypp_1_1solver_1_1detail.html#a8b608bce0af7f994059de7e23f9eb8ed":[3,0,10,39,0,45],
-"namespacezypp_1_1solver_1_1detail.html#a8bf88775f1ff0247c7577595e7822d80":[3,0,10,39,0,18]
+"namespacezypp_1_1sat_1_1detail.html#a7a3025a734f4e8235c12bdc7ae15e634":[3,0,10,37,0,47]
 };
