@@ -1,5 +1,56 @@
 var NAVTREEINDEX114 =
 {
+"structzypp_1_1RW__pointer.html#a88aabd6772a08fa339f7e8c3135dd607":[3,0,10,219,8],
+"structzypp_1_1RW__pointer.html#a88aabd6772a08fa339f7e8c3135dd607":[4,0,7,210,8],
+"structzypp_1_1RW__pointer.html#a89ca661bfa90af85506076b797b745da":[3,0,10,219,24],
+"structzypp_1_1RW__pointer.html#a89ca661bfa90af85506076b797b745da":[4,0,7,210,24],
+"structzypp_1_1RW__pointer.html#a95dfaacc4540215d18afcb78f21021ee":[3,0,10,781],
+"structzypp_1_1RW__pointer.html#a95dfaacc4540215d18afcb78f21021ee":[3,0,10,219,31],
+"structzypp_1_1RW__pointer.html#a95dfaacc4540215d18afcb78f21021ee":[4,0,7,210,31],
+"structzypp_1_1RW__pointer.html#a97991aaf08b995612b50465d03cd98b4":[3,0,10,784],
+"structzypp_1_1RW__pointer.html#a97991aaf08b995612b50465d03cd98b4":[3,0,10,219,34],
+"structzypp_1_1RW__pointer.html#a97991aaf08b995612b50465d03cd98b4":[4,0,7,210,34],
+"structzypp_1_1RW__pointer.html#a99a3b22be83f129dcc31ea7ee3c84859":[3,0,10,791],
+"structzypp_1_1RW__pointer.html#a99a3b22be83f129dcc31ea7ee3c84859":[3,0,10,219,41],
+"structzypp_1_1RW__pointer.html#a99a3b22be83f129dcc31ea7ee3c84859":[4,0,7,210,41],
+"structzypp_1_1RW__pointer.html#ab1894c15b5e445f53ef4af6ec99a7575":[3,0,10,219,16],
+"structzypp_1_1RW__pointer.html#ab1894c15b5e445f53ef4af6ec99a7575":[4,0,7,210,16],
+"structzypp_1_1RW__pointer.html#ab5aae37ca4fed1bd326863f62793b141":[3,0,10,219,13],
+"structzypp_1_1RW__pointer.html#ab5aae37ca4fed1bd326863f62793b141":[4,0,7,210,13],
+"structzypp_1_1RW__pointer.html#abe9cce9a61993796e455db99a2f87e57":[3,0,10,219,18],
+"structzypp_1_1RW__pointer.html#abe9cce9a61993796e455db99a2f87e57":[4,0,7,210,18],
+"structzypp_1_1RW__pointer.html#abf313e75438e491212cfc3a62bf1fafc":[3,0,10,219,22],
+"structzypp_1_1RW__pointer.html#abf313e75438e491212cfc3a62bf1fafc":[4,0,7,210,22],
+"structzypp_1_1RW__pointer.html#ac23844da51218a500031be0619fa7a07":[3,0,10,219,0],
+"structzypp_1_1RW__pointer.html#ac23844da51218a500031be0619fa7a07":[4,0,7,210,0],
+"structzypp_1_1RW__pointer.html#ad279a11caec1d0adf55f09e00ad8b761":[3,0,10,219,3],
+"structzypp_1_1RW__pointer.html#ad279a11caec1d0adf55f09e00ad8b761":[4,0,7,210,3],
+"structzypp_1_1RW__pointer.html#ad4077b5349f2375e6ea878056eb23994":[3,0,10,780],
+"structzypp_1_1RW__pointer.html#ad4077b5349f2375e6ea878056eb23994":[3,0,10,219,30],
+"structzypp_1_1RW__pointer.html#ad4077b5349f2375e6ea878056eb23994":[4,0,7,210,30],
+"structzypp_1_1RW__pointer.html#ad5a4190f32a024f9b146e23a56032771":[3,0,10,219,25],
+"structzypp_1_1RW__pointer.html#ad5a4190f32a024f9b146e23a56032771":[4,0,7,210,25],
+"structzypp_1_1RW__pointer.html#ae8144881538256a75d511495543ed5b1":[3,0,10,782],
+"structzypp_1_1RW__pointer.html#ae8144881538256a75d511495543ed5b1":[3,0,10,219,32],
+"structzypp_1_1RW__pointer.html#ae8144881538256a75d511495543ed5b1":[4,0,7,210,32],
+"structzypp_1_1RW__pointer.html#aec6a16f4f49bd35d98398bcdb4653af1":[3,0,10,219,10],
+"structzypp_1_1RW__pointer.html#aec6a16f4f49bd35d98398bcdb4653af1":[4,0,7,210,10],
+"structzypp_1_1RW__pointer.html#af531c882153d9b995659503cc3065037":[3,0,10,785],
+"structzypp_1_1RW__pointer.html#af531c882153d9b995659503cc3065037":[3,0,10,219,35],
+"structzypp_1_1RW__pointer.html#af531c882153d9b995659503cc3065037":[4,0,7,210,35],
+"structzypp_1_1RW__pointer.html#af88d386fb6f823cee057b167186d7ca2":[3,0,10,219,9],
+"structzypp_1_1RW__pointer.html#af88d386fb6f823cee057b167186d7ca2":[4,0,7,210,9],
+"structzypp_1_1RW__pointer.html#aff753f6866a21a7efe7d7773404dfd63":[3,0,10,778],
+"structzypp_1_1RW__pointer.html#aff753f6866a21a7efe7d7773404dfd63":[3,0,10,219,28],
+"structzypp_1_1RW__pointer.html#aff753f6866a21a7efe7d7773404dfd63":[4,0,7,210,28],
+"structzypp_1_1Range.html":[3,0,10,200],
+"structzypp_1_1Range.html":[4,0,7,191],
+"structzypp_1_1Range.html#a127276b7402497b0ccdec885f114493c":[3,0,10,200,2],
+"structzypp_1_1Range.html#a127276b7402497b0ccdec885f114493c":[4,0,7,191,2],
+"structzypp_1_1Range.html#a1b998a5ff3c7dcd8b0188e672fa748a2":[3,0,10,200,1],
+"structzypp_1_1Range.html#a1b998a5ff3c7dcd8b0188e672fa748a2":[4,0,7,191,1],
+"structzypp_1_1Range.html#a3405293c1953bf78fc483e6a25ad80f5":[3,0,10,200,5],
+"structzypp_1_1Range.html#a3405293c1953bf78fc483e6a25ad80f5":[4,0,7,191,5],
 "structzypp_1_1Range.html#a44bd11555d6eee21c7d4a1a8c21a3a2d":[3,0,10,200,0],
 "structzypp_1_1Range.html#a44bd11555d6eee21c7d4a1a8c21a3a2d":[4,0,7,191,0],
 "structzypp_1_1Range.html#a8578d73ff6cdc417a9ca6c2e90402aa0":[3,0,10,200,4],
@@ -198,56 +249,5 @@ var NAVTREEINDEX114 =
 "structzypp_1_1RepoInfo_1_1Impl.html#ac8bca8521e39422231e98bd1d960107e":[3,0,10,202,0,63],
 "structzypp_1_1RepoInfo_1_1Impl.html#ac8bca8521e39422231e98bd1d960107e":[4,0,7,193,0,63],
 "structzypp_1_1RepoInfo_1_1Impl.html#acce89a4a0469cd45ce56cdcc565583a2":[3,0,10,202,0,53],
-"structzypp_1_1RepoInfo_1_1Impl.html#acce89a4a0469cd45ce56cdcc565583a2":[4,0,7,193,0,53],
-"structzypp_1_1RepoInfo_1_1Impl.html#acd95cf6781aeaa6dee452216476f4c9e":[3,0,10,202,0,57],
-"structzypp_1_1RepoInfo_1_1Impl.html#acd95cf6781aeaa6dee452216476f4c9e":[4,0,7,193,0,57],
-"structzypp_1_1RepoInfo_1_1Impl.html#ad723c51daa232c048f748b95e13ec209":[3,0,10,202,0,62],
-"structzypp_1_1RepoInfo_1_1Impl.html#ad723c51daa232c048f748b95e13ec209":[4,0,7,193,0,62],
-"structzypp_1_1RepoInfo_1_1Impl.html#ad8a562f97c473bce3b6986e0ab359d19":[3,0,10,202,0,7],
-"structzypp_1_1RepoInfo_1_1Impl.html#ad8a562f97c473bce3b6986e0ab359d19":[4,0,7,193,0,7],
-"structzypp_1_1RepoInfo_1_1Impl.html#ade1b1fa77793ad192e2a9f141dd7ca0a":[3,0,10,202,0,15],
-"structzypp_1_1RepoInfo_1_1Impl.html#ade1b1fa77793ad192e2a9f141dd7ca0a":[4,0,7,193,0,15],
-"structzypp_1_1RepoInfo_1_1Impl.html#ae1282a7da3c3ce7d29df9a0b6a0fd04a":[3,0,10,202,0,16],
-"structzypp_1_1RepoInfo_1_1Impl.html#ae1282a7da3c3ce7d29df9a0b6a0fd04a":[4,0,7,193,0,16],
-"structzypp_1_1RepoInfo_1_1Impl.html#ae1c3722a3213c49ee5af927e249f072f":[3,0,10,202,0,58],
-"structzypp_1_1RepoInfo_1_1Impl.html#ae1c3722a3213c49ee5af927e249f072f":[4,0,7,193,0,58],
-"structzypp_1_1RepoInfo_1_1Impl.html#ae552eeb95a48d9aad314e0fae82551b6":[3,0,10,202,0,8],
-"structzypp_1_1RepoInfo_1_1Impl.html#ae552eeb95a48d9aad314e0fae82551b6":[4,0,7,193,0,8],
-"structzypp_1_1RepoInfo_1_1Impl.html#ae7bb136bc06a154096ac1101839fae44":[3,0,10,202,0,4],
-"structzypp_1_1RepoInfo_1_1Impl.html#ae7bb136bc06a154096ac1101839fae44":[4,0,7,193,0,4],
-"structzypp_1_1RepoInfo_1_1Impl.html#aeca454fae4a0b92ca06bfd2b4609a558":[3,0,10,202,0,60],
-"structzypp_1_1RepoInfo_1_1Impl.html#aeca454fae4a0b92ca06bfd2b4609a558":[4,0,7,193,0,60],
-"structzypp_1_1RepoInfo_1_1Impl.html#af0837545469a9ec33edaad11c05196ce":[3,0,10,202,0,73],
-"structzypp_1_1RepoInfo_1_1Impl.html#af0837545469a9ec33edaad11c05196ce":[4,0,7,193,0,73],
-"structzypp_1_1RepoInfo_1_1Impl.html#af3dbb6aa229c20823aa9dbe5889307a6":[3,0,10,202,0,19],
-"structzypp_1_1RepoInfo_1_1Impl.html#af3dbb6aa229c20823aa9dbe5889307a6":[4,0,7,193,0,19],
-"structzypp_1_1RepoInfo_1_1Impl.html#af64954dcbc129be81edbc27a6c91fb95":[3,0,10,202,0,0],
-"structzypp_1_1RepoInfo_1_1Impl.html#af64954dcbc129be81edbc27a6c91fb95":[4,0,7,193,0,0],
-"structzypp_1_1RepoInfo_1_1Impl.html#af865197b82dda5b6f185d95d593661d7":[3,0,10,202,0,46],
-"structzypp_1_1RepoInfo_1_1Impl.html#af865197b82dda5b6f185d95d593661d7":[4,0,7,193,0,46],
-"structzypp_1_1RepoInfo_1_1Impl.html#af9d91d2ab35bc884c5803f7dd2239787":[3,0,10,202,0,54],
-"structzypp_1_1RepoInfo_1_1Impl.html#af9d91d2ab35bc884c5803f7dd2239787":[4,0,7,193,0,54],
-"structzypp_1_1RepoInfo_1_1Impl.html#afada96334ee3774fde9e11688e55c544":[3,0,10,202,0,2],
-"structzypp_1_1RepoInfo_1_1Impl.html#afada96334ee3774fde9e11688e55c544":[4,0,7,193,0,2],
-"structzypp_1_1RepoManagerOptions.html":[3,0,10,204],
-"structzypp_1_1RepoManagerOptions.html":[4,0,7,195],
-"structzypp_1_1RepoManagerOptions.html#a1104bb0639969aac2f2753dd7be2ca8a":[3,0,10,204,10],
-"structzypp_1_1RepoManagerOptions.html#a1104bb0639969aac2f2753dd7be2ca8a":[4,0,7,195,10],
-"structzypp_1_1RepoManagerOptions.html#a23e3d95bdc22eb61e8eacfb89249e573":[3,0,10,204,1],
-"structzypp_1_1RepoManagerOptions.html#a23e3d95bdc22eb61e8eacfb89249e573":[4,0,7,195,1],
-"structzypp_1_1RepoManagerOptions.html#a2a99ae5dca4883f2cbae2ca6cdf85a68":[3,0,10,204,4],
-"structzypp_1_1RepoManagerOptions.html#a2a99ae5dca4883f2cbae2ca6cdf85a68":[4,0,7,195,4],
-"structzypp_1_1RepoManagerOptions.html#a47cb4a3fb7a7954f2c8f305526aab771":[3,0,10,204,6],
-"structzypp_1_1RepoManagerOptions.html#a47cb4a3fb7a7954f2c8f305526aab771":[4,0,7,195,6],
-"structzypp_1_1RepoManagerOptions.html#a62fe5169ed49bf071cc694ad556c4840":[3,0,10,204,2],
-"structzypp_1_1RepoManagerOptions.html#a62fe5169ed49bf071cc694ad556c4840":[4,0,7,195,2],
-"structzypp_1_1RepoManagerOptions.html#a6be373b3dce5c681e116ef6439983766":[3,0,10,204,8],
-"structzypp_1_1RepoManagerOptions.html#a6be373b3dce5c681e116ef6439983766":[4,0,7,195,8],
-"structzypp_1_1RepoManagerOptions.html#a91e34d5fc011897d07ea9135f75dc3a8":[3,0,10,204,9],
-"structzypp_1_1RepoManagerOptions.html#a91e34d5fc011897d07ea9135f75dc3a8":[4,0,7,195,9],
-"structzypp_1_1RepoManagerOptions.html#a9e2e928717006f396e768444a49c023c":[3,0,10,204,11],
-"structzypp_1_1RepoManagerOptions.html#a9e2e928717006f396e768444a49c023c":[4,0,7,195,11],
-"structzypp_1_1RepoManagerOptions.html#aa821b2e932b32166975df1e593959d39":[3,0,10,204,7],
-"structzypp_1_1RepoManagerOptions.html#aa821b2e932b32166975df1e593959d39":[4,0,7,195,7],
-"structzypp_1_1RepoManagerOptions.html#accedc7ade29ea2a89415820eec6d68e5":[3,0,10,204,3]
+"structzypp_1_1RepoInfo_1_1Impl.html#acce89a4a0469cd45ce56cdcc565583a2":[4,0,7,193,0,53]
 };
