@@ -1,21 +1,5 @@
 var NAVTREEINDEX125 =
 {
-"structzypp_1_1rw__pointer_1_1Shared.html#a563b4e0759f4fd5e8ea9a3f1d24ea436":[4,0,7,30,2,0],
-"structzypp_1_1rw__pointer_1_1Shared.html#a8ba42e941395371c734da07cb72885e4":[3,0,10,36,2,5],
-"structzypp_1_1rw__pointer_1_1Shared.html#a8ba42e941395371c734da07cb72885e4":[4,0,7,30,2,5],
-"structzypp_1_1rw__pointer_1_1Shared.html#a998f513a931ced961c0d5491baf1e0dd":[3,0,10,36,2,1],
-"structzypp_1_1rw__pointer_1_1Shared.html#a998f513a931ced961c0d5491baf1e0dd":[4,0,7,30,2,1],
-"structzypp_1_1rw__pointer_1_1Shared.html#a9a927f94c1c8e3ae23e06024d460e0aa":[3,0,10,36,2,4],
-"structzypp_1_1rw__pointer_1_1Shared.html#a9a927f94c1c8e3ae23e06024d460e0aa":[4,0,7,30,2,4],
-"structzypp_1_1rw__pointer_1_1Shared.html#aab5f2ba97d3db937ea89f1779d09995f":[3,0,10,36,2,2],
-"structzypp_1_1rw__pointer_1_1Shared.html#aab5f2ba97d3db937ea89f1779d09995f":[4,0,7,30,2,2],
-"structzypp_1_1rw__pointer_1_1Shared.html#afd21c916c4c9d654c7404c3fc8ff1bd1":[3,0,10,36,2,3],
-"structzypp_1_1rw__pointer_1_1Shared.html#afd21c916c4c9d654c7404c3fc8ff1bd1":[4,0,7,30,2,3],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html":[3,0,10,37,5,0],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html":[4,0,7,31,6,0],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a1ef9aee4d1d4a99702de9c928b5aca49":[3,0,10,37,5,0,0],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a1ef9aee4d1d4a99702de9c928b5aca49":[4,0,7,31,6,0,0],
-"structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a207e60bda772a0258b320b15e234967e":[3,0,10,37,5,0,2],
 "structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a207e60bda772a0258b320b15e234967e":[4,0,7,31,6,0,2],
 "structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a2c4a2134c69f32404187eff115ba1b2e":[3,0,10,37,5,0,3],
 "structzypp_1_1sat_1_1FileConflicts_1_1Conflict.html#a2c4a2134c69f32404187eff115ba1b2e":[4,0,7,31,6,0,3],
@@ -249,5 +233,21 @@ var NAVTREEINDEX125 =
 "structzypp_1_1sat_1_1Transaction_1_1FilterAction.html#a2b2186afd407aeb7bb29091866550f4a":[3,0,10,37,17,0,0],
 "structzypp_1_1sat_1_1Transaction_1_1FilterAction.html#a2b2186afd407aeb7bb29091866550f4a":[4,0,7,31,18,0,0],
 "structzypp_1_1sat_1_1Transaction_1_1FilterAction.html#a887f6d1717de3a108f0f3abbcdb09577":[3,0,10,37,17,0,2],
-"structzypp_1_1sat_1_1Transaction_1_1FilterAction.html#a887f6d1717de3a108f0f3abbcdb09577":[4,0,7,31,18,0,2]
+"structzypp_1_1sat_1_1Transaction_1_1FilterAction.html#a887f6d1717de3a108f0f3abbcdb09577":[4,0,7,31,18,0,2],
+"structzypp_1_1sat_1_1Transaction_1_1FilterAction.html#ad0783e266a3bc9e9a323a2f874b541e0":[3,0,10,37,17,0,3],
+"structzypp_1_1sat_1_1Transaction_1_1FilterAction.html#ad0783e266a3bc9e9a323a2f874b541e0":[4,0,7,31,18,0,3],
+"structzypp_1_1sat_1_1Transaction_1_1FilterAction.html#afb6bedc5ff523638ecb94fb9c82162cc":[3,0,10,37,17,0,1],
+"structzypp_1_1sat_1_1Transaction_1_1FilterAction.html#afb6bedc5ff523638ecb94fb9c82162cc":[4,0,7,31,18,0,1],
+"structzypp_1_1sat_1_1Transaction_1_1Impl.html":[3,0,10,37,17,1],
+"structzypp_1_1sat_1_1Transaction_1_1Impl.html":[4,0,7,31,18,1],
+"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a06108d5f1a6809bc7b2a6966dbc885e3":[3,0,10,37,17,1,26],
+"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a06108d5f1a6809bc7b2a6966dbc885e3":[4,0,7,31,18,1,26],
+"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a06544e5571a14fb6c01d8f3e4095f99b":[3,0,10,37,17,1,4],
+"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a06544e5571a14fb6c01d8f3e4095f99b":[4,0,7,31,18,1,4],
+"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a06a03c2fb0177db088d70efac27553ca":[3,0,10,37,17,1,39],
+"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a06a03c2fb0177db088d70efac27553ca":[4,0,7,31,18,1,39],
+"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a0748bd066790bf20eb21f915ad5bcd48":[3,0,10,37,17,1,19],
+"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a0748bd066790bf20eb21f915ad5bcd48":[4,0,7,31,18,1,19],
+"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a15945fca1fd86ebf2b84616cf991062d":[3,0,10,37,17,1,2],
+"structzypp_1_1sat_1_1Transaction_1_1Impl.html#a15945fca1fd86ebf2b84616cf991062d":[4,0,7,31,18,1,2]
 };
