@@ -1,21 +1,5 @@
 var NAVTREEINDEX132 =
 {
-"structzyppng_1_1NetworkRequestPrivate_1_1pending__t.html#a91c8dfd6b2be5797693b71e268b92d5d":[4,0,9,80,2,0],
-"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html":[3,0,13,118,3],
-"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html":[4,0,9,80,3],
-"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#a22dde46a05a23d9606a519a7578e7455":[3,0,13,118,3,2],
-"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#a22dde46a05a23d9606a519a7578e7455":[4,0,9,80,3,2],
-"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#aba1b459e0df35418dc8d728bc6ba946e":[3,0,13,118,3,0],
-"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#aba1b459e0df35418dc8d728bc6ba946e":[4,0,9,80,3,0],
-"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#ad9448873c442a109ac347a0a74c42549":[3,0,13,118,3,3],
-"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#ad9448873c442a109ac347a0a74c42549":[4,0,9,80,3,3],
-"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#af0920720763b320f2d82396a1112d971":[3,0,13,118,3,1],
-"structzyppng_1_1NetworkRequestPrivate_1_1prepareNextRangeBatch__t.html#af0920720763b320f2d82396a1112d971":[4,0,9,80,3,1],
-"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html":[3,0,13,118,4],
-"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html":[4,0,9,80,4],
-"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a2325a771118296af7315f3ddca14a088":[3,0,13,118,4,10],
-"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a2325a771118296af7315f3ddca14a088":[4,0,9,80,4,10],
-"structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a4cd9e6a27e064d0f5dcf639b9f74190e":[3,0,13,118,4,6],
 "structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a4cd9e6a27e064d0f5dcf639b9f74190e":[4,0,9,80,4,6],
 "structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a572bf76e76041db3bb7c5e12600f43b3":[3,0,13,118,4,5],
 "structzyppng_1_1NetworkRequestPrivate_1_1running__t.html#a572bf76e76041db3bb7c5e12600f43b3":[4,0,9,80,4,5],
@@ -249,5 +233,21 @@ var NAVTREEINDEX132 =
 "structzyppng_1_1SocketPrivate_1_1ConnectingState.html#abd8879f0c0b6893fccd69dc8e9e61cc3":[4,0,9,124,3,4],
 "structzyppng_1_1SocketPrivate_1_1ConnectingState.html#ac7223c9693edf6d570441f1092628cf1":[3,0,13,162,3,0],
 "structzyppng_1_1SocketPrivate_1_1ConnectingState.html#ac7223c9693edf6d570441f1092628cf1":[4,0,9,124,3,0],
-"structzyppng_1_1SocketPrivate_1_1ConnectingState.html#af49a004a50dcb37b52aae6ce05099e56":[3,0,13,162,3,2]
+"structzyppng_1_1SocketPrivate_1_1ConnectingState.html#af49a004a50dcb37b52aae6ce05099e56":[3,0,13,162,3,2],
+"structzyppng_1_1SocketPrivate_1_1ConnectingState.html#af49a004a50dcb37b52aae6ce05099e56":[4,0,9,124,3,2],
+"structzyppng_1_1SocketPrivate_1_1InitialState.html":[3,0,13,162,4],
+"structzyppng_1_1SocketPrivate_1_1InitialState.html":[4,0,9,124,4],
+"structzyppng_1_1SocketPrivate_1_1InitialState.html#aedf0a23e304986ec54ca24bb1f219322":[3,0,13,162,4,0],
+"structzyppng_1_1SocketPrivate_1_1InitialState.html#aedf0a23e304986ec54ca24bb1f219322":[4,0,9,124,4,0],
+"structzyppng_1_1SocketPrivate_1_1ListeningState.html":[3,0,13,162,5],
+"structzyppng_1_1SocketPrivate_1_1ListeningState.html":[4,0,9,124,5],
+"structzyppng_1_1SocketPrivate_1_1ListeningState.html#a2c4c0e2d5b3f1867bf5652eb43cc87de":[3,0,13,162,5,0],
+"structzyppng_1_1SocketPrivate_1_1ListeningState.html#a2c4c0e2d5b3f1867bf5652eb43cc87de":[4,0,9,124,5,0],
+"structzyppng_1_1SocketPrivate_1_1ListeningState.html#a66af95d8e8fde474c9e27806114c12dc":[3,0,13,162,5,1],
+"structzyppng_1_1SocketPrivate_1_1ListeningState.html#a66af95d8e8fde474c9e27806114c12dc":[4,0,9,124,5,1],
+"structzyppng_1_1SocketPrivate_1_1ListeningState.html#adae7be5cc5ec149dbf5f495ead01e2d5":[3,0,13,162,5,3],
+"structzyppng_1_1SocketPrivate_1_1ListeningState.html#adae7be5cc5ec149dbf5f495ead01e2d5":[4,0,9,124,5,3],
+"structzyppng_1_1SocketPrivate_1_1ListeningState.html#afe458e11203c3adc7a2d96d149590513":[3,0,13,162,5,2],
+"structzyppng_1_1SocketPrivate_1_1ListeningState.html#afe458e11203c3adc7a2d96d149590513":[4,0,9,124,5,2],
+"structzyppng_1_1Statemachine_1_1__InitialState.html":[3,0,13,163,0]
 };
