@@ -1,21 +1,5 @@
 var NAVTREEINDEX134 =
 {
-"structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#ac7169f1ca12b0205cde87c2fee9dd844":[4,0,9,1,52,2],
-"structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#acb09daead5ac798f740cc21b4685199d":[3,0,13,15,52,5],
-"structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#acb09daead5ac798f740cc21b4685199d":[4,0,9,1,52,5],
-"structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#af9a1b1b6fdad0f26ac02d94e5c6d6110":[3,0,13,15,52,1],
-"structzyppng_1_1detail_1_1RedoWhileImpl_3_01Task_00_01Pred_00_01std_1_1enable__if__t_3_01is__asy792689a4f95cbf3e14dc4de55394a33b.html#af9a1b1b6fdad0f26ac02d94e5c6d6110":[4,0,9,1,52,1],
-"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html":[3,0,13,15,51],
-"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html":[4,0,9,1,51],
-"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#a32d23b4ce87bf2527923b02d55820804":[3,0,13,15,51,2],
-"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#a32d23b4ce87bf2527923b02d55820804":[4,0,9,1,51,2],
-"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#aa1d9b1a569233b0dba0a1d2e7227b035":[3,0,13,15,51,5],
-"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#aa1d9b1a569233b0dba0a1d2e7227b035":[4,0,9,1,51,5],
-"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#aa419ee11f494159cddd1eeccb34c532c":[3,0,13,15,51,7],
-"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#aa419ee11f494159cddd1eeccb34c532c":[4,0,9,1,51,7],
-"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ab8db9840a5595d0d560bfc79598e5ad4":[3,0,13,15,51,3],
-"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ab8db9840a5595d0d560bfc79598e5ad4":[4,0,9,1,51,3],
-"structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ac09b48c9cfe5e00bfd6376fd24a3fded":[3,0,13,15,51,6],
 "structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ac09b48c9cfe5e00bfd6376fd24a3fded":[4,0,9,1,51,6],
 "structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ac146358fa4b635eb08959d5a6879d425":[3,0,13,15,51,1],
 "structzyppng_1_1detail_1_1RedoWhileImpl_3_01std_1_1shared__ptr_3_01MyAsyncOp_01_4_00_01Pred_00_0e3b822bc630847ea386e12528eaf96f9.html#ac146358fa4b635eb08959d5a6879d425":[4,0,9,1,51,1],
@@ -249,5 +233,21 @@ var NAVTREEINDEX134 =
 "structzyppng_1_1detail_1_1make__statewithtransition__set__helper_3_01VariantSoFar_00_01std_1_1vaedcc3b0aae8ccf9aaaba2595b3c475f8.html":[4,0,9,1,45],
 "structzyppng_1_1detail_1_1make__statewithtransition__set__helper_3_01VariantSoFar_00_01std_1_1vaedcc3b0aae8ccf9aaaba2595b3c475f8.html#a228e8c11e6c55e0096a648d794d3ada5":[3,0,13,15,45,1],
 "structzyppng_1_1detail_1_1make__statewithtransition__set__helper_3_01VariantSoFar_00_01std_1_1vaedcc3b0aae8ccf9aaaba2595b3c475f8.html#a228e8c11e6c55e0096a648d794d3ada5":[4,0,9,1,45,1],
-"structzyppng_1_1detail_1_1make__statewithtransition__set__helper_3_01VariantSoFar_00_01std_1_1vaedcc3b0aae8ccf9aaaba2595b3c475f8.html#aac7b198dfab2fd980ab147cc142270fe":[3,0,13,15,45,0]
+"structzyppng_1_1detail_1_1make__statewithtransition__set__helper_3_01VariantSoFar_00_01std_1_1vaedcc3b0aae8ccf9aaaba2595b3c475f8.html#aac7b198dfab2fd980ab147cc142270fe":[3,0,13,15,45,0],
+"structzyppng_1_1detail_1_1make__statewithtransition__set__helper_3_01VariantSoFar_00_01std_1_1vaedcc3b0aae8ccf9aaaba2595b3c475f8.html#aac7b198dfab2fd980ab147cc142270fe":[4,0,9,1,45,0],
+"structzyppng_1_1detail_1_1mtry__helper.html":[3,0,13,15,47],
+"structzyppng_1_1detail_1_1mtry__helper.html":[4,0,9,1,47],
+"structzyppng_1_1detail_1_1mtry__helper.html#a2f47fe87f6daeac798ef2b1b95d1ad8d":[3,0,13,15,47,1],
+"structzyppng_1_1detail_1_1mtry__helper.html#a2f47fe87f6daeac798ef2b1b95d1ad8d":[4,0,9,1,47,1],
+"structzyppng_1_1detail_1_1mtry__helper.html#abc9382babbe0de1f63ea0d103104930f":[3,0,13,15,47,0],
+"structzyppng_1_1detail_1_1mtry__helper.html#abc9382babbe0de1f63ea0d103104930f":[4,0,9,1,47,0],
+"structzyppng_1_1detail_1_1or__else__helper.html":[3,0,13,15,48],
+"structzyppng_1_1detail_1_1or__else__helper.html":[4,0,9,1,48],
+"structzyppng_1_1detail_1_1or__else__helper.html#a179fd1e8d51de8c8d4ada28c07d01658":[3,0,13,15,48,0],
+"structzyppng_1_1detail_1_1or__else__helper.html#a179fd1e8d51de8c8d4ada28c07d01658":[4,0,9,1,48,0],
+"structzyppng_1_1detail_1_1or__else__helper.html#a6c8ad53ee2f67c3e7ad7ee9af5a51a0d":[3,0,13,15,48,2],
+"structzyppng_1_1detail_1_1or__else__helper.html#a6c8ad53ee2f67c3e7ad7ee9af5a51a0d":[4,0,9,1,48,2],
+"structzyppng_1_1detail_1_1or__else__helper.html#ab981e6614a33c76fd2ff2d14a6893e37":[3,0,13,15,48,1],
+"structzyppng_1_1detail_1_1or__else__helper.html#ab981e6614a33c76fd2ff2d14a6893e37":[4,0,9,1,48,1],
+"structzyppng_1_1detail_1_1showme.html":[3,0,13,15,56]
 };
