@@ -1,7 +1,8 @@
 var NAVTREEINDEX19 =
 {
+"classzypp_1_1IdStringType.html#acc7b3ec0ac2f678d122de5b96643c697":[3,0,10,133,38],
 "classzypp_1_1IdStringType.html#acc7b3ec0ac2f678d122de5b96643c697":[4,0,7,124,38],
-"classzypp_1_1IdStringType.html#acfa466f97a85784c0976a23fa26d5cca":[3,0,10,698],
+"classzypp_1_1IdStringType.html#acfa466f97a85784c0976a23fa26d5cca":[3,0,10,707],
 "classzypp_1_1IdStringType.html#acfa466f97a85784c0976a23fa26d5cca":[3,0,10,133,44],
 "classzypp_1_1IdStringType.html#acfa466f97a85784c0976a23fa26d5cca":[4,0,7,124,44],
 "classzypp_1_1IdStringType.html#acfbe9a1ee4406272c34fb4ef81b338a0":[3,0,10,133,13],
@@ -14,7 +15,7 @@ var NAVTREEINDEX19 =
 "classzypp_1_1IdStringType.html#add68b5af8adf63ab0e27f8d41d04cc66":[4,0,7,124,2],
 "classzypp_1_1IdStringType.html#ade64242196383f13ba9054e85f82c3cb":[3,0,10,133,26],
 "classzypp_1_1IdStringType.html#ade64242196383f13ba9054e85f82c3cb":[4,0,7,124,26],
-"classzypp_1_1IdStringType.html#ae0f758cb9aca71b4ba86fe89fdd7a0b6":[3,0,10,693],
+"classzypp_1_1IdStringType.html#ae0f758cb9aca71b4ba86fe89fdd7a0b6":[3,0,10,702],
 "classzypp_1_1IdStringType.html#ae0f758cb9aca71b4ba86fe89fdd7a0b6":[3,0,10,133,39],
 "classzypp_1_1IdStringType.html#ae0f758cb9aca71b4ba86fe89fdd7a0b6":[4,0,7,124,39],
 "classzypp_1_1IdStringType.html#ae12ae9dfce3a4be8ec49d3cd68a3aa6e":[3,0,10,133,12],
@@ -55,7 +56,7 @@ var NAVTREEINDEX19 =
 "classzypp_1_1InputStream.html#a860ea2cf5575915464967546527ba105":[4,0,7,125,13],
 "classzypp_1_1InputStream.html#a938478a7e857e2be4cc4e1477e6c1adb":[3,0,10,134,8],
 "classzypp_1_1InputStream.html#a938478a7e857e2be4cc4e1477e6c1adb":[4,0,7,125,8],
-"classzypp_1_1InputStream.html#a987f8d2138cbafefd116fd0738fb11b8":[3,0,10,765],
+"classzypp_1_1InputStream.html#a987f8d2138cbafefd116fd0738fb11b8":[3,0,10,774],
 "classzypp_1_1InputStream.html#a987f8d2138cbafefd116fd0738fb11b8":[3,0,10,134,15],
 "classzypp_1_1InputStream.html#a987f8d2138cbafefd116fd0738fb11b8":[4,0,7,125,15],
 "classzypp_1_1InputStream.html#a99580fbd827096016fbacc0f71d9116f":[3,0,10,134,16],
@@ -122,7 +123,7 @@ var NAVTREEINDEX19 =
 "classzypp_1_1Iterable.html#a3a1b1cfd1040996f7699c26b97807c7a":[4,0,7,127,6],
 "classzypp_1_1Iterable.html#a4c2cb69d1f1e76782eca95f47be6098a":[3,0,10,136,15],
 "classzypp_1_1Iterable.html#a4c2cb69d1f1e76782eca95f47be6098a":[4,0,7,127,15],
-"classzypp_1_1Iterable.html#a5ad47f28021047da9f8cb710ff0f5eec":[3,0,10,766],
+"classzypp_1_1Iterable.html#a5ad47f28021047da9f8cb710ff0f5eec":[3,0,10,775],
 "classzypp_1_1Iterable.html#a5ad47f28021047da9f8cb710ff0f5eec":[3,0,10,136,16],
 "classzypp_1_1Iterable.html#a5ad47f28021047da9f8cb710ff0f5eec":[4,0,7,127,16],
 "classzypp_1_1Iterable.html#a819f96b87c5bbe1c8cc66a1f71d3a554":[3,0,10,136,0],
@@ -131,7 +132,7 @@ var NAVTREEINDEX19 =
 "classzypp_1_1Iterable.html#a8fcea1377fe584f60021b3c7d47d5064":[4,0,7,127,1],
 "classzypp_1_1Iterable.html#a9a4cbae3172ca5abdfe730a3da59e9dd":[3,0,10,136,12],
 "classzypp_1_1Iterable.html#a9a4cbae3172ca5abdfe730a3da59e9dd":[4,0,7,127,12],
-"classzypp_1_1Iterable.html#a9c870789c2e9007d68e6f868b8d150ee":[3,0,10,767],
+"classzypp_1_1Iterable.html#a9c870789c2e9007d68e6f868b8d150ee":[3,0,10,776],
 "classzypp_1_1Iterable.html#a9c870789c2e9007d68e6f868b8d150ee":[3,0,10,136,17],
 "classzypp_1_1Iterable.html#a9c870789c2e9007d68e6f868b8d150ee":[4,0,7,127,17],
 "classzypp_1_1Iterable.html#ab02048786ffa80d08e64342c6fca33b3":[3,0,10,136,2],
@@ -152,7 +153,7 @@ var NAVTREEINDEX19 =
 "classzypp_1_1Iterable.html#afa288758170ab6c33d6282b5d43f4586":[4,0,7,127,5],
 "classzypp_1_1KeyRing.html":[3,0,10,139],
 "classzypp_1_1KeyRing.html":[4,0,7,130],
-"classzypp_1_1KeyRing.html#a0aa09dbf5063fe81c5da19bd2eab56d2":[3,0,10,700],
+"classzypp_1_1KeyRing.html#a0aa09dbf5063fe81c5da19bd2eab56d2":[3,0,10,709],
 "classzypp_1_1KeyRing.html#a0aa09dbf5063fe81c5da19bd2eab56d2":[3,0,10,139,29],
 "classzypp_1_1KeyRing.html#a0aa09dbf5063fe81c5da19bd2eab56d2":[4,0,7,130,29],
 "classzypp_1_1KeyRing.html#a13a9bb9a03d30f4e8cbd6cc7cd28396e":[3,0,10,139,22],
@@ -248,6 +249,5 @@ var NAVTREEINDEX19 =
 "classzypp_1_1LanguageCode.html#aca6cc43cd5eca0425f594b5a6e19f165":[3,0,10,143,3],
 "classzypp_1_1LanguageCode.html#aca6cc43cd5eca0425f594b5a6e19f165":[4,0,7,134,3],
 "classzypp_1_1LanguageCode.html#ae9de469ba6674611acd89ea4b7c85a46":[3,0,10,143,7],
-"classzypp_1_1LanguageCode.html#ae9de469ba6674611acd89ea4b7c85a46":[4,0,7,134,7],
-"classzypp_1_1Locale.html":[3,0,10,144]
+"classzypp_1_1LanguageCode.html#ae9de469ba6674611acd89ea4b7c85a46":[4,0,7,134,7]
 };
