@@ -1,5 +1,6 @@
 var NAVTREEINDEX20 =
 {
+"classzypp_1_1Locale.html":[3,0,10,144],
 "classzypp_1_1Locale.html":[4,0,7,135],
 "classzypp_1_1Locale.html#a1deb809f09cb933a4d18b296d7851ded":[3,0,10,144,1],
 "classzypp_1_1Locale.html#a1deb809f09cb933a4d18b296d7851ded":[4,0,7,135,1],
@@ -243,11 +244,10 @@ var NAVTREEINDEX20 =
 "classzypp_1_1Match.html#a39b780ae90fc27568fc8d4772fe4b2d5":[4,0,7,144,43],
 "classzypp_1_1Match.html#a3afa3999736979a354a6e69c82722945":[3,0,10,153,21],
 "classzypp_1_1Match.html#a3afa3999736979a354a6e69c82722945":[4,0,7,144,21],
-"classzypp_1_1Match.html#a43e8e0209f7aac544e3fc24c1bdd6b14":[3,0,10,648],
+"classzypp_1_1Match.html#a43e8e0209f7aac544e3fc24c1bdd6b14":[3,0,10,657],
 "classzypp_1_1Match.html#a43e8e0209f7aac544e3fc24c1bdd6b14":[3,0,10,153,36],
 "classzypp_1_1Match.html#a43e8e0209f7aac544e3fc24c1bdd6b14":[4,0,7,144,36],
 "classzypp_1_1Match.html#a47ab73e748499663710913ea86ce0cf4":[3,0,10,153,19],
 "classzypp_1_1Match.html#a47ab73e748499663710913ea86ce0cf4":[4,0,7,144,19],
-"classzypp_1_1Match.html#a488f816b693de9dbf5f52411eac27260":[3,0,10,153,24],
-"classzypp_1_1Match.html#a488f816b693de9dbf5f52411eac27260":[4,0,7,144,24]
+"classzypp_1_1Match.html#a488f816b693de9dbf5f52411eac27260":[3,0,10,153,24]
 };
