@@ -1,5 +1,7 @@
 var NAVTREEINDEX24 =
 {
+"classzypp_1_1PathInfo.html#a00bdc5d6e865b49d9d06031ab39e43d0":[4,0,7,166,74],
+"classzypp_1_1PathInfo.html#a03313c378d8675f7a349ef34a4f262e5":[3,0,10,175,51],
 "classzypp_1_1PathInfo.html#a03313c378d8675f7a349ef34a4f262e5":[4,0,7,166,51],
 "classzypp_1_1PathInfo.html#a08834fcec4b2021a1b129aa7bcf24282":[3,0,10,175,48],
 "classzypp_1_1PathInfo.html#a08834fcec4b2021a1b129aa7bcf24282":[4,0,7,166,48],
@@ -247,7 +249,5 @@ var NAVTREEINDEX24 =
 "classzypp_1_1Pathname.html#ae967e6a93eccdb006a3c3f4974241b9e":[4,0,7,167,29],
 "classzypp_1_1Pathname.html#af16267032a0c3f19170eaa8ee81495a5":[3,0,10,176,24],
 "classzypp_1_1Pathname.html#af16267032a0c3f19170eaa8ee81495a5":[4,0,7,167,24],
-"classzypp_1_1Pathname.html#afbf2a5125650d999b5df2330c6240ced":[3,0,10,176,45],
-"classzypp_1_1Pathname.html#afbf2a5125650d999b5df2330c6240ced":[4,0,7,167,45],
-"classzypp_1_1Pathname.html#afd0d3c6bfe302b4e7affe60598d396c4":[3,0,10,176,18]
+"classzypp_1_1Pathname.html#afbf2a5125650d999b5df2330c6240ced":[3,0,10,176,45]
 };
