@@ -1,5 +1,7 @@
 var NAVTREEINDEX32 =
 {
+"classzypp_1_1ResPool.html#a50d1ef8520ab322a1212e301efd92a2b":[4,0,7,204,88],
+"classzypp_1_1ResPool.html#a518ac2197735e00eedcfe346481e7af6":[3,0,10,213,73],
 "classzypp_1_1ResPool.html#a518ac2197735e00eedcfe346481e7af6":[4,0,7,204,73],
 "classzypp_1_1ResPool.html#a52c4c9f7fc969ce405337d3fa2996ff7":[3,0,10,213,72],
 "classzypp_1_1ResPool.html#a52c4c9f7fc969ce405337d3fa2996ff7":[4,0,7,204,72],
@@ -247,7 +249,5 @@ var NAVTREEINDEX32 =
 "classzypp_1_1ResPoolProxy.html#af564dc925a2355942300e48df6dbb410":[4,0,7,205,31],
 "classzypp_1_1ResPoolProxy.html#af6f03bd80f4fdc8be17f27d323573bc6":[3,0,10,214,44],
 "classzypp_1_1ResPoolProxy.html#af6f03bd80f4fdc8be17f27d323573bc6":[4,0,7,205,44],
-"classzypp_1_1ResPoolProxy.html#afa1602f0353acc490827263e100b7212":[3,0,10,214,24],
-"classzypp_1_1ResPoolProxy.html#afa1602f0353acc490827263e100b7212":[4,0,7,205,24],
-"classzypp_1_1ResPoolProxy.html#affdda0a780f6910e6909303f109fefd5":[3,0,10,214,43]
+"classzypp_1_1ResPoolProxy.html#afa1602f0353acc490827263e100b7212":[3,0,10,214,24]
 };
