@@ -1,5 +1,7 @@
 var NAVTREEINDEX35 =
 {
+"classzypp_1_1Resolver.html#a93c30aecbc3a4c08aef64aeef2e81901":[3,0,10,211,18],
+"classzypp_1_1Resolver.html#a93c30aecbc3a4c08aef64aeef2e81901":[4,0,7,202,18],
 "classzypp_1_1Resolver.html#a948e96e3adc3b0b443f9932c609edaab":[3,0,10,211,48],
 "classzypp_1_1Resolver.html#a948e96e3adc3b0b443f9932c609edaab":[4,0,7,202,48],
 "classzypp_1_1Resolver.html#a9fb1d4704a1e50ae45a6433f415cd283":[3,0,10,211,75],
@@ -247,7 +249,5 @@ var NAVTREEINDEX35 =
 "classzypp_1_1ShutdownLock.html#a28324535e9ff00e2453ba8124c210c61":[4,0,7,217,1],
 "classzypp_1_1ShutdownLock.html#a4c6a23e9e9b97f60aa962103982ddccc":[3,0,10,226,2],
 "classzypp_1_1ShutdownLock.html#a4c6a23e9e9b97f60aa962103982ddccc":[4,0,7,217,2],
-"classzypp_1_1ShutdownLock.html#ab9e16086e83c0809f3df4e3f14a923c8":[3,0,10,226,0],
-"classzypp_1_1ShutdownLock.html#ab9e16086e83c0809f3df4e3f14a923c8":[4,0,7,217,0],
-"classzypp_1_1SignalSaver.html":[3,0,10,227]
+"classzypp_1_1ShutdownLock.html#ab9e16086e83c0809f3df4e3f14a923c8":[3,0,10,226,0]
 };
