@@ -1,5 +1,6 @@
 var NAVTREEINDEX4 =
 {
+"Testcase_8h_source.html":[5,0,0,8,0,26],
 "Testcase__helix_8cc.html":[5,0,0,8,0,27],
 "Testcase__helix_8cc.html#a8ebe294fd4c0f922e5139df116a02a0e":[5,0,0,8,0,27,4],
 "Testcase__helix_8cc.html#a91364c7a384a14bcfd5a0cc7fa6150c8":[5,0,0,8,0,27,2],
@@ -11,8 +12,8 @@ var NAVTREEINDEX4 =
 "Transaction_8cc_source.html":[5,0,0,7,25],
 "Transaction_8h.html":[5,0,0,7,26],
 "Transaction_8h_source.html":[5,0,0,7,26],
-"TransferSettings_8h.html":[5,0,0,1,43],
-"TransferSettings_8h_source.html":[5,0,0,1,43],
+"TransferSettings_8h.html":[5,0,0,1,41],
+"TransferSettings_8h_source.html":[5,0,0,1,41],
 "TypeTraits_8h.html":[5,0,0,0,55],
 "TypeTraits_8h_source.html":[5,0,0,0,55],
 "Types_8h.html":[5,0,0,8,1],
@@ -27,15 +28,15 @@ var NAVTREEINDEX4 =
 "UrlBase_8cc.html#a4592a05961855b4b3ade3a20e9c8667f":[5,0,1,5,0,5],
 "UrlBase_8cc.html#ab1ae8cc77b23f54a52b02e125d82b282":[5,0,1,5,0,7],
 "UrlBase_8cc_source.html":[5,0,1,5,0],
-"UrlResolverPlugin_8cc.html":[5,0,0,1,44],
-"UrlResolverPlugin_8cc_source.html":[5,0,0,1,44],
-"UrlResolverPlugin_8h.html":[5,0,0,1,45],
-"UrlResolverPlugin_8h_source.html":[5,0,0,1,45],
+"UrlResolverPlugin_8cc.html":[5,0,0,1,42],
+"UrlResolverPlugin_8cc_source.html":[5,0,0,1,42],
+"UrlResolverPlugin_8h.html":[5,0,0,1,43],
+"UrlResolverPlugin_8h_source.html":[5,0,0,1,43],
 "UrlUtils_8cc.html":[5,0,1,5,3],
 "UrlUtils_8cc_source.html":[5,0,1,5,3],
-"Url_8cc.html":[5,0,1,29],
-"Url_8cc.html#acaa2d7d2cad21508c73975d12fe4c5c1":[5,0,1,29,0],
-"Url_8cc_source.html":[5,0,1,29],
+"Url_8cc.html":[5,0,1,31],
+"Url_8cc.html#acaa2d7d2cad21508c73975d12fe4c5c1":[5,0,1,31,0],
+"Url_8cc_source.html":[5,0,1,31],
 "UserRequestException_8h.html":[5,0,0,0,57],
 "UserRequestException_8h_source.html":[5,0,0,0,57],
 "UserWantedPackages_8cc.html":[5,0,0,10,8],
@@ -248,6 +249,5 @@ var NAVTREEINDEX4 =
 "classhelix_1_1detail_1_1XmlNode.html#aada18f79e7802d45159e0da7c18bfee5":[3,0,1,0,1,1],
 "classhelix_1_1detail_1_1XmlNode.html#aada18f79e7802d45159e0da7c18bfee5":[4,0,0,0,1,1],
 "classhelix_1_1detail_1_1XmlNode.html#ab8a7f38cd8f1033e339090b76be120fd":[3,0,1,0,1,2],
-"classhelix_1_1detail_1_1XmlNode.html#ab8a7f38cd8f1033e339090b76be120fd":[4,0,0,0,1,2],
-"classhelix_1_1detail_1_1XmlNode.html#ac886bcbe084f8df51e343e0f899c0780":[3,0,1,0,1,8]
+"classhelix_1_1detail_1_1XmlNode.html#ab8a7f38cd8f1033e339090b76be120fd":[4,0,0,0,1,2]
 };
