@@ -1,5 +1,7 @@
 var NAVTREEINDEX40 =
 {
+"classzypp_1_1ZYppFactory.html#a65442f900ce19daf2aaeb88a4dec7dcf":[4,0,7,240,3],
+"classzypp_1_1ZYppFactory.html#a9fdc84b76ce4ed06e0540097b92795b7":[3,0,10,249,0],
 "classzypp_1_1ZYppFactory.html#a9fdc84b76ce4ed06e0540097b92795b7":[4,0,7,240,0],
 "classzypp_1_1ZYppFactory.html#adf9737a8b2fd77e48c0ce9e3e0aadcbd":[3,0,10,249,1],
 "classzypp_1_1ZYppFactory.html#adf9737a8b2fd77e48c0ce9e3e0aadcbd":[4,0,7,240,1],
@@ -247,7 +249,5 @@ var NAVTREEINDEX40 =
 "classzypp_1_1base_1_1LogControl.html#a501f7bfe30bef8e56f85f6ad397c1dbf":[4,0,7,1,3,16],
 "classzypp_1_1base_1_1LogControl.html#a6bbdfe5898d9f94999cb35051907a13b":[3,0,10,2,29],
 "classzypp_1_1base_1_1LogControl.html#a6bbdfe5898d9f94999cb35051907a13b":[3,0,10,2,4,18],
-"classzypp_1_1base_1_1LogControl.html#a6bbdfe5898d9f94999cb35051907a13b":[4,0,7,1,3,18],
-"classzypp_1_1base_1_1LogControl.html#a796163313cde8c22c6c2b52e9d5f3e6c":[3,0,10,2,4,11],
-"classzypp_1_1base_1_1LogControl.html#a796163313cde8c22c6c2b52e9d5f3e6c":[4,0,7,1,3,11]
+"classzypp_1_1base_1_1LogControl.html#a6bbdfe5898d9f94999cb35051907a13b":[4,0,7,1,3,18]
 };
