@@ -1,5 +1,7 @@
 var NAVTREEINDEX42 =
 {
+"classzypp_1_1bit_1_1BitField.html#ad29610309310b073e12a4211b14049da":[3,0,10,3,1,35],
+"classzypp_1_1bit_1_1BitField.html#ad29610309310b073e12a4211b14049da":[4,0,7,2,1,35],
 "classzypp_1_1bit_1_1BitField.html#ad3367c2e486525d8c426d01dac6de965":[3,0,10,3,1,10],
 "classzypp_1_1bit_1_1BitField.html#ad3367c2e486525d8c426d01dac6de965":[4,0,7,2,1,10],
 "classzypp_1_1bit_1_1BitField.html#ae1694ae9c2588b3908629d7d7b1a02ed":[3,0,10,3,1,12],
@@ -247,7 +249,5 @@ var NAVTREEINDEX42 =
 "classzypp_1_1detail_1_1PoolQueryMatcher.html#ac049e760a2748731b9593ecc7f58b6b6":[4,0,7,5,6,5],
 "classzypp_1_1detail_1_1PoolQueryMatcher.html#ac6e8c57c122a63717448ff38bbcb0e53":[3,0,10,6,6,13],
 "classzypp_1_1detail_1_1PoolQueryMatcher.html#ac6e8c57c122a63717448ff38bbcb0e53":[4,0,7,5,6,13],
-"classzypp_1_1detail_1_1PoolQueryMatcher.html#ac888eef10e094b4d1ffc70b116bf50c5":[3,0,10,6,6,16],
-"classzypp_1_1detail_1_1PoolQueryMatcher.html#ac888eef10e094b4d1ffc70b116bf50c5":[4,0,7,5,6,16],
-"classzypp_1_1detail_1_1PoolQueryMatcher.html#ae001b9e447efb99c42f7585babdb223b":[3,0,10,6,6,7]
+"classzypp_1_1detail_1_1PoolQueryMatcher.html#ac888eef10e094b4d1ffc70b116bf50c5":[3,0,10,6,6,16]
 };
