@@ -1,5 +1,6 @@
 var NAVTREEINDEX5 =
 {
+"classhelix_1_1detail_1_1XmlNode.html#ac886bcbe084f8df51e343e0f899c0780":[3,0,1,0,1,8],
 "classhelix_1_1detail_1_1XmlNode.html#ac886bcbe084f8df51e343e0f899c0780":[4,0,0,0,1,8],
 "classhelix_1_1detail_1_1XmlNode.html#ad3371ba08c383c32cb162c6963c0caa3":[3,0,1,0,1,12],
 "classhelix_1_1detail_1_1XmlNode.html#ad3371ba08c383c32cb162c6963c0caa3":[4,0,0,0,1,12],
@@ -248,6 +249,5 @@ var NAVTREEINDEX5 =
 "classztui_1_1Out.html#a4865dac69cb013f4d9b55890e9294899":[4,0,6,12,22],
 "classztui_1_1Out.html#a4d95220fd5e3896bae158e682cd3e5b1":[3,0,9,15,45],
 "classztui_1_1Out.html#a4d95220fd5e3896bae158e682cd3e5b1":[4,0,6,12,45],
-"classztui_1_1Out.html#a4ee51890e9d409a39049d6f17ba1a5a2":[3,0,9,15,38],
-"classztui_1_1Out.html#a4ee51890e9d409a39049d6f17ba1a5a2":[4,0,6,12,38]
+"classztui_1_1Out.html#a4ee51890e9d409a39049d6f17ba1a5a2":[3,0,9,15,38]
 };
