@@ -1,5 +1,7 @@
 var NAVTREEINDEX58 =
 {
+"classzypp_1_1pool_1_1PoolImpl.html#ade396b5fa36f9f8f3ac20d5224f99a7d":[4,0,7,26,3,3],
+"classzypp_1_1pool_1_1PoolImpl.html#ae4cb62810e40dd1bf2a4c4229cd6ab0b":[3,0,10,29,3,6],
 "classzypp_1_1pool_1_1PoolImpl.html#ae4cb62810e40dd1bf2a4c4229cd6ab0b":[4,0,7,26,3,6],
 "classzypp_1_1pool_1_1PoolImpl.html#ae6c89bcba1927ed001ce64b8831a065c":[3,0,10,29,3,32],
 "classzypp_1_1pool_1_1PoolImpl.html#ae6c89bcba1927ed001ce64b8831a065c":[4,0,7,26,3,32],
@@ -247,7 +249,5 @@ var NAVTREEINDEX58 =
 "classzypp_1_1repo_1_1RepoInvalidAliasException.html":[4,0,7,27,12],
 "classzypp_1_1repo_1_1RepoInvalidAliasException.html#a0596a506d307bd863fe0637b7ccc2a20":[3,0,10,32,13,0],
 "classzypp_1_1repo_1_1RepoInvalidAliasException.html#a0596a506d307bd863fe0637b7ccc2a20":[4,0,7,27,12,0],
-"classzypp_1_1repo_1_1RepoInvalidAliasException.html#a384148165c6da50b848be1883f71c2b7":[3,0,10,32,13,3],
-"classzypp_1_1repo_1_1RepoInvalidAliasException.html#a384148165c6da50b848be1883f71c2b7":[4,0,7,27,12,3],
-"classzypp_1_1repo_1_1RepoInvalidAliasException.html#aa01de78e542fe36d6db227c2b074a725":[3,0,10,32,13,1]
+"classzypp_1_1repo_1_1RepoInvalidAliasException.html#a384148165c6da50b848be1883f71c2b7":[3,0,10,32,13,3]
 };
