@@ -1,5 +1,7 @@
 var NAVTREEINDEX59 =
 {
+"classzypp_1_1repo_1_1RepoInvalidAliasException.html#a384148165c6da50b848be1883f71c2b7":[4,0,7,27,12,3],
+"classzypp_1_1repo_1_1RepoInvalidAliasException.html#aa01de78e542fe36d6db227c2b074a725":[3,0,10,32,13,1],
 "classzypp_1_1repo_1_1RepoInvalidAliasException.html#aa01de78e542fe36d6db227c2b074a725":[4,0,7,27,12,1],
 "classzypp_1_1repo_1_1RepoInvalidAliasException.html#aa15f2d41ea404267aab5adfe99d2c107":[3,0,10,32,13,2],
 "classzypp_1_1repo_1_1RepoInvalidAliasException.html#aa15f2d41ea404267aab5adfe99d2c107":[4,0,7,27,12,2],
@@ -247,7 +249,5 @@ var NAVTREEINDEX59 =
 "classzypp_1_1repo_1_1ServiceInvalidAliasException.html#a1072e54888257ec68ab138ae785600b8":[4,0,7,27,31,3],
 "classzypp_1_1repo_1_1ServiceInvalidAliasException.html#a3d52388115c2d08f18bfae994667302d":[3,0,10,32,32,0],
 "classzypp_1_1repo_1_1ServiceInvalidAliasException.html#a3d52388115c2d08f18bfae994667302d":[4,0,7,27,31,0],
-"classzypp_1_1repo_1_1ServiceInvalidAliasException.html#a60d1a8ab861ba576e62519cc8d098566":[3,0,10,32,32,2],
-"classzypp_1_1repo_1_1ServiceInvalidAliasException.html#a60d1a8ab861ba576e62519cc8d098566":[4,0,7,27,31,2],
-"classzypp_1_1repo_1_1ServiceInvalidAliasException.html#abf41bbefec013fa271eab313471fee15":[3,0,10,32,32,1]
+"classzypp_1_1repo_1_1ServiceInvalidAliasException.html#a60d1a8ab861ba576e62519cc8d098566":[3,0,10,32,32,2]
 };
