@@ -1,5 +1,7 @@
 var NAVTREEINDEX60 =
 {
+"classzypp_1_1repo_1_1ServiceInvalidAliasException.html#a60d1a8ab861ba576e62519cc8d098566":[4,0,7,27,31,2],
+"classzypp_1_1repo_1_1ServiceInvalidAliasException.html#abf41bbefec013fa271eab313471fee15":[3,0,10,32,32,1],
 "classzypp_1_1repo_1_1ServiceInvalidAliasException.html#abf41bbefec013fa271eab313471fee15":[4,0,7,27,31,1],
 "classzypp_1_1repo_1_1ServiceNoAliasException.html":[3,0,10,32,33],
 "classzypp_1_1repo_1_1ServiceNoAliasException.html":[4,0,7,27,32],
@@ -247,7 +249,5 @@ var NAVTREEINDEX60 =
 "classzypp_1_1sat_1_1LookupAttr.html#aebd383f101b21a389bfae78161c170cf":[3,0,10,37,7,27],
 "classzypp_1_1sat_1_1LookupAttr.html#aebd383f101b21a389bfae78161c170cf":[4,0,7,31,8,27],
 "classzypp_1_1sat_1_1LookupAttr.html#af7f47657ad76dbda9b8d895365d33569":[3,0,10,37,7,33],
-"classzypp_1_1sat_1_1LookupAttr.html#af7f47657ad76dbda9b8d895365d33569":[4,0,7,31,8,33],
-"classzypp_1_1sat_1_1LookupAttr.html#afaee6d0bea6e3fcbe9983965e8cbe69c":[3,0,10,37,7,11],
-"classzypp_1_1sat_1_1LookupAttr.html#afaee6d0bea6e3fcbe9983965e8cbe69c":[4,0,7,31,8,11]
+"classzypp_1_1sat_1_1LookupAttr.html#af7f47657ad76dbda9b8d895365d33569":[4,0,7,31,8,33]
 };
