@@ -1,5 +1,7 @@
 var NAVTREEINDEX64 =
 {
+"classzypp_1_1sat_1_1Solvable.html#a0b4efb77a00cc0ff20638833bb19c5a4":[3,0,10,37,12,7],
+"classzypp_1_1sat_1_1Solvable.html#a0b4efb77a00cc0ff20638833bb19c5a4":[4,0,7,31,13,7],
 "classzypp_1_1sat_1_1Solvable.html#a0bb9ebf1b941548776d64c6f4fc03fc1":[3,0,10,37,117],
 "classzypp_1_1sat_1_1Solvable.html#a0bb9ebf1b941548776d64c6f4fc03fc1":[3,0,10,37,12,95],
 "classzypp_1_1sat_1_1Solvable.html#a0bb9ebf1b941548776d64c6f4fc03fc1":[4,0,7,31,13,95],
@@ -247,7 +249,5 @@ var NAVTREEINDEX64 =
 "classzypp_1_1sat_1_1SolvableSet.html#aa4b92708b5df52e334001bf4fbeb53e9":[4,0,7,31,14,10],
 "classzypp_1_1sat_1_1SolvableSet.html#aa8d1cc425b733e4dba61ba48be663798":[3,0,10,37,13,16],
 "classzypp_1_1sat_1_1SolvableSet.html#aa8d1cc425b733e4dba61ba48be663798":[4,0,7,31,14,16],
-"classzypp_1_1sat_1_1SolvableSet.html#aa908e190279fa5c4a3a2e72458db62a3":[3,0,10,37,13,8],
-"classzypp_1_1sat_1_1SolvableSet.html#aa908e190279fa5c4a3a2e72458db62a3":[4,0,7,31,14,8],
-"classzypp_1_1sat_1_1SolvableSet.html#aad3d22079fe0cca4402b41034b9a52d8":[3,0,10,37,13,13]
+"classzypp_1_1sat_1_1SolvableSet.html#aa908e190279fa5c4a3a2e72458db62a3":[3,0,10,37,13,8]
 };
