@@ -1,5 +1,7 @@
 var NAVTREEINDEX65 =
 {
+"classzypp_1_1sat_1_1SolvableSet.html#aa908e190279fa5c4a3a2e72458db62a3":[4,0,7,31,14,8],
+"classzypp_1_1sat_1_1SolvableSet.html#aad3d22079fe0cca4402b41034b9a52d8":[3,0,10,37,13,13],
 "classzypp_1_1sat_1_1SolvableSet.html#aad3d22079fe0cca4402b41034b9a52d8":[4,0,7,31,14,13],
 "classzypp_1_1sat_1_1SolvableSet.html#ab84202cab488dc64c8b77d02f96a72ba":[3,0,10,37,13,4],
 "classzypp_1_1sat_1_1SolvableSet.html#ab84202cab488dc64c8b77d02f96a72ba":[4,0,7,31,14,4],
@@ -247,7 +249,5 @@ var NAVTREEINDEX65 =
 "classzypp_1_1sat_1_1WhatProvides.html#a55d1d35cb03f8ca21df25725409a8b64":[3,0,10,37,19,1],
 "classzypp_1_1sat_1_1WhatProvides.html#a55d1d35cb03f8ca21df25725409a8b64":[4,0,7,31,20,1],
 "classzypp_1_1sat_1_1WhatProvides.html#a61a8ed233aca670629ffe12c42dab984":[3,0,10,37,19,7],
-"classzypp_1_1sat_1_1WhatProvides.html#a61a8ed233aca670629ffe12c42dab984":[4,0,7,31,20,7],
-"classzypp_1_1sat_1_1WhatProvides.html#a89ff5dd3eb0b72a33e0a41d5c2c03cd5":[3,0,10,37,19,5],
-"classzypp_1_1sat_1_1WhatProvides.html#a89ff5dd3eb0b72a33e0a41d5c2c03cd5":[4,0,7,31,20,5]
+"classzypp_1_1sat_1_1WhatProvides.html#a61a8ed233aca670629ffe12c42dab984":[4,0,7,31,20,7]
 };
