@@ -1,5 +1,7 @@
 var NAVTREEINDEX70 =
 {
+"classzypp_1_1target_1_1SolvIdentFile.html#ad6d892a227b69327bd176dd061c14a4b":[4,0,7,36,15,4],
+"classzypp_1_1target_1_1SolvIdentFile.html#afb972b3de64cdd51b3a8a9553de7409e":[3,0,10,43,15,2],
 "classzypp_1_1target_1_1SolvIdentFile.html#afb972b3de64cdd51b3a8a9553de7409e":[4,0,7,36,15,2],
 "classzypp_1_1target_1_1TargetAbortedException.html":[3,0,10,43,16],
 "classzypp_1_1target_1_1TargetAbortedException.html":[4,0,7,36,16],
@@ -247,7 +249,5 @@ var NAVTREEINDEX70 =
 "classzypp_1_1target_1_1rpm_1_1RpmDb.html#a125baf3bebee3b1da593bce5e1d5471c":[3,0,10,43,0,17,22],
 "classzypp_1_1target_1_1rpm_1_1RpmDb.html#a125baf3bebee3b1da593bce5e1d5471c":[4,0,7,36,0,16,22],
 "classzypp_1_1target_1_1rpm_1_1RpmDb.html#a17fd2b4764d603a54491efe8d9e8b474":[3,0,10,43,0,17,32],
-"classzypp_1_1target_1_1rpm_1_1RpmDb.html#a17fd2b4764d603a54491efe8d9e8b474":[4,0,7,36,0,16,32],
-"classzypp_1_1target_1_1rpm_1_1RpmDb.html#a18af31219554740e00d161c1ec321a37":[3,0,10,43,0,17,46],
-"classzypp_1_1target_1_1rpm_1_1RpmDb.html#a18af31219554740e00d161c1ec321a37":[4,0,7,36,0,16,46]
+"classzypp_1_1target_1_1rpm_1_1RpmDb.html#a17fd2b4764d603a54491efe8d9e8b474":[4,0,7,36,0,16,32]
 };
