@@ -1,5 +1,7 @@
 var NAVTREEINDEX71 =
 {
+"classzypp_1_1target_1_1rpm_1_1RpmDb.html#a18af31219554740e00d161c1ec321a37":[3,0,10,43,0,17,46],
+"classzypp_1_1target_1_1rpm_1_1RpmDb.html#a18af31219554740e00d161c1ec321a37":[4,0,7,36,0,16,46],
 "classzypp_1_1target_1_1rpm_1_1RpmDb.html#a18ce1fa7a90a49e993974a9ef2f014ba":[3,0,10,43,0,17,29],
 "classzypp_1_1target_1_1rpm_1_1RpmDb.html#a18ce1fa7a90a49e993974a9ef2f014ba":[4,0,7,36,0,16,29],
 "classzypp_1_1target_1_1rpm_1_1RpmDb.html#a19ae3d4bac0fca12ce5bbc03ecf663b3":[3,0,10,43,0,17,2],
@@ -247,7 +249,5 @@ var NAVTREEINDEX71 =
 "classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a814c2e1bc9124fc8c9df82e1ba09a7f5":[3,0,10,43,0,23,58],
 "classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a814c2e1bc9124fc8c9df82e1ba09a7f5":[4,0,7,36,0,22,58],
 "classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a89a9347d45de27530884daf17f95f5e9":[3,0,10,43,0,23,37],
-"classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a89a9347d45de27530884daf17f95f5e9":[4,0,7,36,0,22,37],
-"classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a90a160c29333e94b8e5c1d14d286b949":[3,0,10,43,0,23,55],
-"classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a90a160c29333e94b8e5c1d14d286b949":[4,0,7,36,0,22,55]
+"classzypp_1_1target_1_1rpm_1_1RpmHeader.html#a89a9347d45de27530884daf17f95f5e9":[4,0,7,36,0,22,37]
 };
