@@ -1,5 +1,7 @@
 var NAVTREEINDEX73 =
 {
+"classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#a9adb161c03de58890ddd7be5460a22cb":[3,0,10,43,0,12,1,0,0],
+"classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#a9adb161c03de58890ddd7be5460a22cb":[4,0,7,36,0,11,1,0,0],
 "classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#aa7188af8694ada671c75d44bab102115":[3,0,10,43,0,12,1,0,9],
 "classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#aa7188af8694ada671c75d44bab102115":[4,0,7,36,0,11,1,0,9],
 "classzypp_1_1target_1_1rpm_1_1librpmDb_1_1db__const__iterator_1_1D.html#ab08c57b6397fae8261b31a68f8de25e9":[3,0,10,43,0,12,1,0,14],
@@ -247,7 +249,5 @@ var NAVTREEINDEX73 =
 "classzypp_1_1ui_1_1StatusBackup.html":[3,0,10,45,4],
 "classzypp_1_1ui_1_1StatusBackup.html":[4,0,7,37,4],
 "classzypp_1_1ui_1_1StatusBackup.html#a076a486f83032174f36965ba8158b823":[3,0,10,45,4,12],
-"classzypp_1_1ui_1_1StatusBackup.html#a076a486f83032174f36965ba8158b823":[4,0,7,37,4,12],
-"classzypp_1_1ui_1_1StatusBackup.html#a11d1f0fbccadfac37a2271b1e654a86a":[3,0,10,45,4,11],
-"classzypp_1_1ui_1_1StatusBackup.html#a11d1f0fbccadfac37a2271b1e654a86a":[4,0,7,37,4,11]
+"classzypp_1_1ui_1_1StatusBackup.html#a076a486f83032174f36965ba8158b823":[4,0,7,37,4,12]
 };
