@@ -1,5 +1,7 @@
 var NAVTREEINDEX74 =
 {
+"classzypp_1_1ui_1_1StatusBackup.html#a11d1f0fbccadfac37a2271b1e654a86a":[3,0,10,45,4,11],
+"classzypp_1_1ui_1_1StatusBackup.html#a11d1f0fbccadfac37a2271b1e654a86a":[4,0,7,37,4,11],
 "classzypp_1_1ui_1_1StatusBackup.html#a2af33786e2f6f6136f12c8e6b551fbba":[3,0,10,45,4,1],
 "classzypp_1_1ui_1_1StatusBackup.html#a2af33786e2f6f6136f12c8e6b551fbba":[4,0,7,37,4,1],
 "classzypp_1_1ui_1_1StatusBackup.html#a2ec883c7392063b86d8a696c38e4ed7d":[3,0,10,45,4,16],
@@ -247,7 +249,5 @@ var NAVTREEINDEX74 =
 "classzypp_1_1url_1_1UrlNotSupportedException.html#ac5f67d3978b66ca37fd51ec6315b7be8":[3,0,10,46,7,1],
 "classzypp_1_1url_1_1UrlNotSupportedException.html#ac5f67d3978b66ca37fd51ec6315b7be8":[4,0,7,38,7,1],
 "classzypp_1_1url_1_1UrlNotSupportedException.html#acd53e15fafb48710adc06c9f54bc4185":[3,0,10,46,7,2],
-"classzypp_1_1url_1_1UrlNotSupportedException.html#acd53e15fafb48710adc06c9f54bc4185":[4,0,7,38,7,2],
-"classzypp_1_1url_1_1UrlParsingException.html":[3,0,10,46,8],
-"classzypp_1_1url_1_1UrlParsingException.html":[4,0,7,38,8]
+"classzypp_1_1url_1_1UrlNotSupportedException.html#acd53e15fafb48710adc06c9f54bc4185":[4,0,7,38,7,2]
 };
