@@ -1,5 +1,7 @@
 var NAVTREEINDEX85 =
 {
+"classzyppng_1_1ProgressObserverPrivate.html#a5e81e894a1af6bb5a4a332c5aff1b057":[4,0,9,87,15],
+"classzyppng_1_1ProgressObserverPrivate.html#a71b148b6f5ba37bcd2ea3005de65f715":[3,0,13,125,14],
 "classzyppng_1_1ProgressObserverPrivate.html#a71b148b6f5ba37bcd2ea3005de65f715":[4,0,9,87,14],
 "classzyppng_1_1ProgressObserverPrivate.html#a7b5b108d8342ea902c9746ca6630ffa6":[3,0,13,125,25],
 "classzyppng_1_1ProgressObserverPrivate.html#a7b5b108d8342ea902c9746ca6630ffa6":[4,0,9,87,25],
@@ -247,7 +249,5 @@ var NAVTREEINDEX85 =
 "classzyppng_1_1ProvideFileSpec_1_1Impl.html#a11cfce0875d725134a3fa31d77e4f372":[4,0,9,90,0,0],
 "classzyppng_1_1ProvideFileSpec_1_1Impl.html#a136243cf687237d4c45968634582870c":[3,0,13,128,0,8],
 "classzyppng_1_1ProvideFileSpec_1_1Impl.html#a136243cf687237d4c45968634582870c":[4,0,9,90,0,8],
-"classzyppng_1_1ProvideFileSpec_1_1Impl.html#a1d49e3502cac5f150f609274918eba16":[3,0,13,128,0,6],
-"classzyppng_1_1ProvideFileSpec_1_1Impl.html#a1d49e3502cac5f150f609274918eba16":[4,0,9,90,0,6],
-"classzyppng_1_1ProvideFileSpec_1_1Impl.html#a3d5abf3be46e7f2d21bf9eadfed9c7d5":[3,0,13,128,0,10]
+"classzyppng_1_1ProvideFileSpec_1_1Impl.html#a1d49e3502cac5f150f609274918eba16":[3,0,13,128,0,6]
 };
