@@ -7,16 +7,66 @@ var NAVTREEINDEX92 =
 "classzyppng_1_1WorkerCaps.html#af39aa3e072beffd45fbc2e642a9f83d1":[4,0,9,143,15],
 "classzyppng_1_1WorkerCaps.html#afde2fc3fe969cc1975ad3f6e35a4a89a":[3,0,13,181,14],
 "classzyppng_1_1WorkerCaps.html#afde2fc3fe969cc1975ad3f6e35a4a89a":[4,0,9,143,14],
-"classzyppng_1_1ZckHelper.html":[3,0,13,182],
-"classzyppng_1_1ZckHelper.html":[4,0,9,144],
-"classzyppng_1_1ZckHelper.html#a4f16c8512023607543f11f0b26d0d40c":[3,0,13,182,1],
-"classzyppng_1_1ZckHelper.html#a4f16c8512023607543f11f0b26d0d40c":[4,0,9,144,1],
-"classzyppng_1_1ZckHelper.html#a5eef7cafc54142abd190cd289938f209":[3,0,13,182,4],
-"classzyppng_1_1ZckHelper.html#a5eef7cafc54142abd190cd289938f209":[4,0,9,144,4],
-"classzyppng_1_1ZckHelper.html#ab0e59d0d0b8ee2a9cd5acd1b2a28beb5":[3,0,13,182,2],
-"classzyppng_1_1ZckHelper.html#ab0e59d0d0b8ee2a9cd5acd1b2a28beb5":[4,0,9,144,2],
-"classzyppng_1_1ZckHelper.html#ae0d4760759309b37050267752b57ea0f":[3,0,13,182,3],
-"classzyppng_1_1ZckHelper.html#ae0d4760759309b37050267752b57ea0f":[4,0,9,144,3],
+"classzyppng_1_1ZckError.html":[3,0,13,182],
+"classzyppng_1_1ZckError.html":[4,0,9,144],
+"classzyppng_1_1ZckError.html#a5afc69d6da6e8693c67f4435133109c6":[3,0,13,182,0],
+"classzyppng_1_1ZckError.html#a5afc69d6da6e8693c67f4435133109c6":[4,0,9,144,0],
+"classzyppng_1_1ZckError.html#ac70aac77cd8899bea8f6b524ed0daa02":[3,0,13,182,1],
+"classzyppng_1_1ZckError.html#ac70aac77cd8899bea8f6b524ed0daa02":[4,0,9,144,1],
+"classzyppng_1_1ZckLoader.html":[3,0,13,183],
+"classzyppng_1_1ZckLoader.html":[4,0,9,145],
+"classzyppng_1_1ZckLoader.html#a0c5271b970eed076c095ff1c8f76fa72":[3,0,13,183,10],
+"classzyppng_1_1ZckLoader.html#a0c5271b970eed076c095ff1c8f76fa72":[4,0,9,145,10],
+"classzyppng_1_1ZckLoader.html#a1aaa04aa3b6668ca1fe7387b21f1ab44":[3,0,13,183,11],
+"classzyppng_1_1ZckLoader.html#a1aaa04aa3b6668ca1fe7387b21f1ab44":[4,0,9,145,11],
+"classzyppng_1_1ZckLoader.html#a270ee283c3f3e64d8bdebea27450b6b9":[3,0,13,183,5],
+"classzyppng_1_1ZckLoader.html#a270ee283c3f3e64d8bdebea27450b6b9":[4,0,9,145,5],
+"classzyppng_1_1ZckLoader.html#a48a757cbf1f40250494c6ae925ead957":[3,0,13,183,18],
+"classzyppng_1_1ZckLoader.html#a48a757cbf1f40250494c6ae925ead957":[4,0,9,145,18],
+"classzyppng_1_1ZckLoader.html#a50d1618cd41c355d0d888ce59927ce9b":[3,0,13,183,3],
+"classzyppng_1_1ZckLoader.html#a50d1618cd41c355d0d888ce59927ce9b":[4,0,9,145,3],
+"classzyppng_1_1ZckLoader.html#a582d761234fc5c6e6a2cf30b713a683c":[3,0,13,183,4],
+"classzyppng_1_1ZckLoader.html#a582d761234fc5c6e6a2cf30b713a683c":[4,0,9,145,4],
+"classzyppng_1_1ZckLoader.html#a5b2970ad7e830578e20f0b2a10468192":[3,0,13,183,21],
+"classzyppng_1_1ZckLoader.html#a5b2970ad7e830578e20f0b2a10468192":[4,0,9,145,21],
+"classzyppng_1_1ZckLoader.html#a82d54012f9b12b4514fd1fcaabac46b0":[3,0,13,183,17],
+"classzyppng_1_1ZckLoader.html#a82d54012f9b12b4514fd1fcaabac46b0":[4,0,9,145,17],
+"classzyppng_1_1ZckLoader.html#a83ff694f71f69688aeec5237ad6c440e":[3,0,13,183,15],
+"classzyppng_1_1ZckLoader.html#a83ff694f71f69688aeec5237ad6c440e":[4,0,9,145,15],
+"classzyppng_1_1ZckLoader.html#a9ad80727571583f7cefe3b289d72c142":[3,0,13,183,7],
+"classzyppng_1_1ZckLoader.html#a9ad80727571583f7cefe3b289d72c142":[4,0,9,145,7],
+"classzyppng_1_1ZckLoader.html#a9d8b56c1c0f2ec85366713ec32bfaac9":[3,0,13,183,13],
+"classzyppng_1_1ZckLoader.html#a9d8b56c1c0f2ec85366713ec32bfaac9":[4,0,9,145,13],
+"classzyppng_1_1ZckLoader.html#ab39578834ad3603ceceed7d8e435aeda":[3,0,13,183,1],
+"classzyppng_1_1ZckLoader.html#ab39578834ad3603ceceed7d8e435aeda":[4,0,9,145,1],
+"classzyppng_1_1ZckLoader.html#ac2676edf2205540c4b5d3a74a5391f64":[3,0,13,183,16],
+"classzyppng_1_1ZckLoader.html#ac2676edf2205540c4b5d3a74a5391f64":[4,0,9,145,16],
+"classzyppng_1_1ZckLoader.html#ac76839d10f63c0f2fd77fcecf3b0fce1":[3,0,13,183,9],
+"classzyppng_1_1ZckLoader.html#ac76839d10f63c0f2fd77fcecf3b0fce1":[4,0,9,145,9],
+"classzyppng_1_1ZckLoader.html#ad08940110dbd9ccaf11fb1c99d12ae18":[3,0,13,183,2],
+"classzyppng_1_1ZckLoader.html#ad08940110dbd9ccaf11fb1c99d12ae18":[4,0,9,145,2],
+"classzyppng_1_1ZckLoader.html#ad08940110dbd9ccaf11fb1c99d12ae18a1500f2c88ee6fed7e3078cb858420bd8":[3,0,13,183,2,1],
+"classzyppng_1_1ZckLoader.html#ad08940110dbd9ccaf11fb1c99d12ae18a1500f2c88ee6fed7e3078cb858420bd8":[4,0,9,145,2,1],
+"classzyppng_1_1ZckLoader.html#ad08940110dbd9ccaf11fb1c99d12ae18a90789da9d51fb16d3f6869b7d456c1e0":[3,0,13,183,2,4],
+"classzyppng_1_1ZckLoader.html#ad08940110dbd9ccaf11fb1c99d12ae18a90789da9d51fb16d3f6869b7d456c1e0":[4,0,9,145,2,4],
+"classzyppng_1_1ZckLoader.html#ad08940110dbd9ccaf11fb1c99d12ae18aa9b630437d58667250e4e0cedcd9625e":[3,0,13,183,2,3],
+"classzyppng_1_1ZckLoader.html#ad08940110dbd9ccaf11fb1c99d12ae18aa9b630437d58667250e4e0cedcd9625e":[4,0,9,145,2,3],
+"classzyppng_1_1ZckLoader.html#ad08940110dbd9ccaf11fb1c99d12ae18adf47ce993ff2302e909692acefd16aa4":[3,0,13,183,2,2],
+"classzyppng_1_1ZckLoader.html#ad08940110dbd9ccaf11fb1c99d12ae18adf47ce993ff2302e909692acefd16aa4":[4,0,9,145,2,2],
+"classzyppng_1_1ZckLoader.html#ad08940110dbd9ccaf11fb1c99d12ae18af131603700252f0c42e35114d4403d76":[3,0,13,183,2,0],
+"classzyppng_1_1ZckLoader.html#ad08940110dbd9ccaf11fb1c99d12ae18af131603700252f0c42e35114d4403d76":[4,0,9,145,2,0],
+"classzyppng_1_1ZckLoader.html#ad2820c5878b29ecec02c4ae6bf34fcd7":[3,0,13,183,6],
+"classzyppng_1_1ZckLoader.html#ad2820c5878b29ecec02c4ae6bf34fcd7":[4,0,9,145,6],
+"classzyppng_1_1ZckLoader.html#ad58cc2b2edc0cece1ab8aa2c385d63b7":[3,0,13,183,8],
+"classzyppng_1_1ZckLoader.html#ad58cc2b2edc0cece1ab8aa2c385d63b7":[4,0,9,145,8],
+"classzyppng_1_1ZckLoader.html#ad68e04bfb21fefd5e8e48cae0d698fee":[3,0,13,183,20],
+"classzyppng_1_1ZckLoader.html#ad68e04bfb21fefd5e8e48cae0d698fee":[4,0,9,145,20],
+"classzyppng_1_1ZckLoader.html#ae238daf0fc379a71a65473a47b29d640":[3,0,13,183,19],
+"classzyppng_1_1ZckLoader.html#ae238daf0fc379a71a65473a47b29d640":[4,0,9,145,19],
+"classzyppng_1_1ZckLoader.html#ae579f620c931f5635383bf8568b5b203":[3,0,13,183,14],
+"classzyppng_1_1ZckLoader.html#ae579f620c931f5635383bf8568b5b203":[4,0,9,145,14],
+"classzyppng_1_1ZckLoader.html#af378d5d071cd29c111a2fb099e11a840":[3,0,13,183,12],
+"classzyppng_1_1ZckLoader.html#af378d5d071cd29c111a2fb099e11a840":[4,0,9,145,12],
 "classzyppng_1_1detail_1_1ReportHolder.html":[3,0,13,15,53],
 "classzyppng_1_1detail_1_1ReportHolder.html":[4,0,9,1,53],
 "classzyppng_1_1detail_1_1ReportHolder_3_01ContextRef_00_01Report_01_4.html":[3,0,13,15,54],
@@ -199,55 +249,5 @@ var NAVTREEINDEX92 =
 "classzyppng_1_1repo_1_1RefreshContext.html#a2d148b9a078b94255a16d22122d5126e":[4,0,9,5,1,32],
 "classzyppng_1_1repo_1_1RefreshContext.html#a35e3d239712c674395cd72b384e4e18e":[3,0,13,33,1,33],
 "classzyppng_1_1repo_1_1RefreshContext.html#a35e3d239712c674395cd72b384e4e18e":[4,0,9,5,1,33],
-"classzyppng_1_1repo_1_1RefreshContext.html#a3d9407d82f3bc5241d9858bde020d9d0":[3,0,13,33,1,30],
-"classzyppng_1_1repo_1_1RefreshContext.html#a3d9407d82f3bc5241d9858bde020d9d0":[4,0,9,5,1,30],
-"classzyppng_1_1repo_1_1RefreshContext.html#a3f42f0a5dd416c85d43b075a69a09dc3":[3,0,13,33,1,18],
-"classzyppng_1_1repo_1_1RefreshContext.html#a3f42f0a5dd416c85d43b075a69a09dc3":[4,0,9,5,1,18],
-"classzyppng_1_1repo_1_1RefreshContext.html#a45b4075c0ecd726937425d399da0f824":[3,0,13,33,1,7],
-"classzyppng_1_1repo_1_1RefreshContext.html#a45b4075c0ecd726937425d399da0f824":[4,0,9,5,1,7],
-"classzyppng_1_1repo_1_1RefreshContext.html#a489cb0c49cbaff210ba534a70c731dc5":[3,0,13,33,1,2],
-"classzyppng_1_1repo_1_1RefreshContext.html#a489cb0c49cbaff210ba534a70c731dc5":[4,0,9,5,1,2],
-"classzyppng_1_1repo_1_1RefreshContext.html#a4d636de05137598a5387479bab9a5907":[3,0,13,33,1,20],
-"classzyppng_1_1repo_1_1RefreshContext.html#a4d636de05137598a5387479bab9a5907":[4,0,9,5,1,20],
-"classzyppng_1_1repo_1_1RefreshContext.html#a4dffbfc78ad9b3aa3d805f0bc20f79a7":[3,0,13,33,1,8],
-"classzyppng_1_1repo_1_1RefreshContext.html#a4dffbfc78ad9b3aa3d805f0bc20f79a7":[4,0,9,5,1,8],
-"classzyppng_1_1repo_1_1RefreshContext.html#a5096f93262bf5d480c8f8ac75c2601e2":[3,0,13,33,1,10],
-"classzyppng_1_1repo_1_1RefreshContext.html#a5096f93262bf5d480c8f8ac75c2601e2":[4,0,9,5,1,10],
-"classzyppng_1_1repo_1_1RefreshContext.html#a67e04d890276273108c0ea54dd0ea9e4":[3,0,13,33,1,6],
-"classzyppng_1_1repo_1_1RefreshContext.html#a67e04d890276273108c0ea54dd0ea9e4":[4,0,9,5,1,6],
-"classzyppng_1_1repo_1_1RefreshContext.html#a82f376a2e95e744c3175d1157bd04a40":[3,0,13,33,1,21],
-"classzyppng_1_1repo_1_1RefreshContext.html#a82f376a2e95e744c3175d1157bd04a40":[4,0,9,5,1,21],
-"classzyppng_1_1repo_1_1RefreshContext.html#a878873443d0c5e1bda0c2e2884f68216":[3,0,13,33,1,19],
-"classzyppng_1_1repo_1_1RefreshContext.html#a878873443d0c5e1bda0c2e2884f68216":[4,0,9,5,1,19],
-"classzyppng_1_1repo_1_1RefreshContext.html#a98fb4b576c94d111f5beb26cae6657f5":[3,0,13,33,1,13],
-"classzyppng_1_1repo_1_1RefreshContext.html#a98fb4b576c94d111f5beb26cae6657f5":[4,0,9,5,1,13],
-"classzyppng_1_1repo_1_1RefreshContext.html#a9c02c0bed9ed165867a4bfbb9e734bba":[3,0,13,33,1,31],
-"classzyppng_1_1repo_1_1RefreshContext.html#a9c02c0bed9ed165867a4bfbb9e734bba":[4,0,9,5,1,31],
-"classzyppng_1_1repo_1_1RefreshContext.html#a9e94e5ac066df27c9d878041e09d20ba":[3,0,13,33,1,26],
-"classzyppng_1_1repo_1_1RefreshContext.html#a9e94e5ac066df27c9d878041e09d20ba":[4,0,9,5,1,26],
-"classzyppng_1_1repo_1_1RefreshContext.html#aa78689b797df55efa08ac75f0dd4499d":[3,0,13,33,1,14],
-"classzyppng_1_1repo_1_1RefreshContext.html#aa78689b797df55efa08ac75f0dd4499d":[4,0,9,5,1,14],
-"classzyppng_1_1repo_1_1RefreshContext.html#aa80f39503f3a28d3c11e8e6de485012b":[3,0,13,33,1,27],
-"classzyppng_1_1repo_1_1RefreshContext.html#aa80f39503f3a28d3c11e8e6de485012b":[4,0,9,5,1,27],
-"classzyppng_1_1repo_1_1RefreshContext.html#ab5fb3613f9381dc35b05b63c178c9cf3":[3,0,13,33,1,11],
-"classzyppng_1_1repo_1_1RefreshContext.html#ab5fb3613f9381dc35b05b63c178c9cf3":[4,0,9,5,1,11],
-"classzyppng_1_1repo_1_1RefreshContext.html#ab68fed42f1217fc9292eb18129b6f432":[3,0,13,33,1,4],
-"classzyppng_1_1repo_1_1RefreshContext.html#ab68fed42f1217fc9292eb18129b6f432":[4,0,9,5,1,4],
-"classzyppng_1_1repo_1_1RefreshContext.html#ab8fdc1b4d4f94c8cdd2fe654c5ee7e0c":[3,0,13,33,1,34],
-"classzyppng_1_1repo_1_1RefreshContext.html#ab8fdc1b4d4f94c8cdd2fe654c5ee7e0c":[4,0,9,5,1,34],
-"classzyppng_1_1repo_1_1RefreshContext.html#ad320c31e98d4350319e2d830a2ea8913":[3,0,13,33,1,22],
-"classzyppng_1_1repo_1_1RefreshContext.html#ad320c31e98d4350319e2d830a2ea8913":[4,0,9,5,1,22],
-"classzyppng_1_1repo_1_1RefreshContext.html#adb8a49fa5beca293ab97f49c889907b9":[3,0,13,33,1,15],
-"classzyppng_1_1repo_1_1RefreshContext.html#adb8a49fa5beca293ab97f49c889907b9":[4,0,9,5,1,15],
-"classzyppng_1_1repo_1_1RefreshContext.html#adc696afd3db9f809ad2cb80e4cc91f16":[3,0,13,33,1,29],
-"classzyppng_1_1repo_1_1RefreshContext.html#adc696afd3db9f809ad2cb80e4cc91f16":[4,0,9,5,1,29],
-"classzyppng_1_1repo_1_1RefreshContext.html#ae310ca97e4aa6c1f17426be8cb429d67":[3,0,13,33,1,25],
-"classzyppng_1_1repo_1_1RefreshContext.html#ae310ca97e4aa6c1f17426be8cb429d67":[4,0,9,5,1,25],
-"classzyppng_1_1repo_1_1RefreshContext.html#afa9802e3b9020c9549290830911d1662":[3,0,13,33,1,3],
-"classzyppng_1_1repo_1_1RefreshContext.html#afa9802e3b9020c9549290830911d1662":[4,0,9,5,1,3],
-"classzyppng_1_1repo_1_1RefreshContext.html#afc8e591b9e5ad0b63750e5567294c576":[3,0,13,33,1,0],
-"classzyppng_1_1repo_1_1RefreshContext.html#afc8e591b9e5ad0b63750e5567294c576":[4,0,9,5,1,0],
-"classzyppng_1_1worker_1_1DeviceDriver.html":[3,0,13,44,4],
-"classzyppng_1_1worker_1_1DeviceDriver.html":[4,0,9,6,4],
-"classzyppng_1_1worker_1_1DeviceDriver.html#a0564d2efb40a68f854a54f78cb282e08":[3,0,13,44,4,12]
+"classzyppng_1_1repo_1_1RefreshContext.html#a3d9407d82f3bc5241d9858bde020d9d0":[3,0,13,33,1,30]
 };
