@@ -1,5 +1,55 @@
 var NAVTREEINDEX98 =
 {
+"namespacezypp.html#a5aad5e8a94c95d6f796cf31aa8e234f9":[3,0,10,336],
+"namespacezypp.html#a5aeb804a51e14e803c96d655ff5a775c":[3,0,10,325],
+"namespacezypp.html#a5e4fbf9007f6727d3461ec600a01c8ac":[3,0,10,463],
+"namespacezypp.html#a5ecbdcb8e13f11b169fb30ebc6ba29c6":[3,0,10,403],
+"namespacezypp.html#a5f43b4b9677f1fa380a8981f81adf22c":[3,0,10,480],
+"namespacezypp.html#a5f4622b7cb42b3d3e232a3be12d2a0b9":[3,0,10,836],
+"namespacezypp.html#a600b015d21dffa99c1e66d44dfa5a9a3":[3,0,10,365],
+"namespacezypp.html#a601df053500c36942ee92391baaeb273":[3,0,10,827],
+"namespacezypp.html#a6106d8475613c2547f91c3babfa583f6":[3,0,10,320],
+"namespacezypp.html#a610b545d549a5d3663b27bab916abb19":[3,0,10,842],
+"namespacezypp.html#a617054fca720a157d917093df635923d":[3,0,10,271],
+"namespacezypp.html#a617387156911635966f21b24da17d6f0":[3,0,10,317],
+"namespacezypp.html#a61b220b944e6b813565c351036e8b52c":[3,0,10,614],
+"namespacezypp.html#a66fac46e8c2038c4610d1d6313099fe1":[3,0,10,477],
+"namespacezypp.html#a673c11d7a391065376a282dcbb2d86e4":[3,0,10,575],
+"namespacezypp.html#a67401adfcb997b869e60a2b58fdcc0a0":[3,0,10,574],
+"namespacezypp.html#a68b254152878ed984c1121742f14b34d":[3,0,10,388],
+"namespacezypp.html#a68b83a05c95b39a5c4816098891200d4":[3,0,10,341],
+"namespacezypp.html#a68cee8bc7de729bc8c2f2839fa809a45":[3,0,10,431],
+"namespacezypp.html#a690cc4aa9400c6e3c30ab756359f87c3":[3,0,10,312],
+"namespacezypp.html#a69347eebb3dd41ae5f706282a73bb3f2":[3,0,10,473],
+"namespacezypp.html#a69684966637b94e36e3b977095a13b66":[3,0,10,430],
+"namespacezypp.html#a69d40417026da1aa41db3063d6adbab4":[3,0,10,511],
+"namespacezypp.html#a6ae1328f8cccb7929dbfb4f2bc8a4cae":[3,0,10,505],
+"namespacezypp.html#a6b48b19a3c6ef48da7f834acefc04add":[3,0,10,378],
+"namespacezypp.html#a6b68cca1f863d6f1c31e6254bba59def":[3,0,10,381],
+"namespacezypp.html#a6c47cf12b821b9ac63ad880d0e6dbb6b":[3,0,10,621],
+"namespacezypp.html#a6d388c0e9798dc35fc1be9876374d537":[3,0,10,529],
+"namespacezypp.html#a6d97a82534910b19869856b8221aa9e3":[3,0,10,598],
+"namespacezypp.html#a6da6df570a1fcf35fe3c6a8c7fc3a99a":[3,0,10,597],
+"namespacezypp.html#a6daf6de2371ba670de6df270dd0aa1d4":[3,0,10,462],
+"namespacezypp.html#a6e39d67141f5e282321ca13596e7b6a5":[3,0,10,432],
+"namespacezypp.html#a6e3d4e803240931a2fac85c014dd7c21":[3,0,10,269],
+"namespacezypp.html#a6f39a51fd234208a8dcc628db60337e8":[3,0,10,397],
+"namespacezypp.html#a70551d49a0fb77d0fa8e23bd21bad108":[3,0,10,391],
+"namespacezypp.html#a70d49f91ddefbc53d0b61e22932514f4":[3,0,10,580],
+"namespacezypp.html#a719c51e615d199bf9c50d766443dc657":[3,0,10,569],
+"namespacezypp.html#a71ae9116142104fd61a41b9d85a6cbe1":[3,0,10,294],
+"namespacezypp.html#a7303a7bed92c69cc6ba23fb7467fbcd0":[3,0,10,476],
+"namespacezypp.html#a73ad579d85727f175761d3e4561563eb":[3,0,10,258],
+"namespacezypp.html#a747115c895642ca3b201e8190af4f46a":[3,0,10,563],
+"namespacezypp.html#a75642e5aecb5b96857dfa2159a2590ad":[3,0,10,275],
+"namespacezypp.html#a75740e6227569db7bd74932316d9305f":[3,0,10,478],
+"namespacezypp.html#a76a4f1d6e6cb06f1c896700d1a33d21d":[3,0,10,498],
+"namespacezypp.html#a772f8cec822e93842d99a8ac4e11f854":[3,0,10,503],
+"namespacezypp.html#a785a1bf8e92999a1c7a3ef8c373527d7":[3,0,10,408],
+"namespacezypp.html#a786df3cf123484fbee62a0b6023ccdb3":[3,0,10,841],
+"namespacezypp.html#a7abb7cd6847874a1b589b6a1e16379a6":[3,0,10,382],
+"namespacezypp.html#a7c6c36111c52dde2fa60b7c9dcb7f247":[3,0,10,634],
+"namespacezypp.html#a7c6f91d0fd4fdeadb739ec1fd0c3375e":[3,0,10,295],
 "namespacezypp.html#a7cce3d6f533245e1710eadbe0909ec12":[3,0,10,608],
 "namespacezypp.html#a7dab952ab3fa93f989196b9c5983545d":[3,0,10,405],
 "namespacezypp.html#a7e90ee3d56a61dc608dbaafda680ff3a":[3,0,10,573],
@@ -199,55 +249,5 @@ var NAVTREEINDEX98 =
 "namespacezypp.html#af905a25440f3efaeb1daa211b8e2b124":[3,0,10,542],
 "namespacezypp.html#af971e6b698969f3a267c36aa3de7aff3":[3,0,10,552],
 "namespacezypp.html#afa4b23860344803aa3704779cc7f41bb":[3,0,10,465],
-"namespacezypp.html#afa53946d82e433de1744649a0b6d30f1":[3,0,10,450],
-"namespacezypp.html#afab4562a88924d3f7915e082f47ee2f8":[3,0,10,519],
-"namespacezypp.html#afc77b7533216fe47b21dc56a3557382d":[3,0,10,530],
-"namespacezypp.html#afd150b4b833ecb255abd3e12477b616e":[3,0,10,488],
-"namespacezypp.html#afd3fe495355837c55c1aec8b1363edd8":[3,0,10,266],
-"namespacezypp.html#afd4d0bd0d161217947e983dcc9dcca8c":[3,0,10,446],
-"namespacezypp.html#afdd1ae180b46ec5116b6e99ad61f3d2f":[3,0,10,284],
-"namespacezypp.html#aff0a5458dd3d0a9dd37b1484c5787420":[3,0,10,280],
-"namespacezypp.html#aff0a5458dd3d0a9dd37b1484c5787420ae94073d823aada00d826a0859990e356":[3,0,10,280,3],
-"namespacezypp.html#aff0a5458dd3d0a9dd37b1484c5787420af06a07a653c79d4e8240ca0c05c17be1":[3,0,10,280,1],
-"namespacezypp.html#aff0a5458dd3d0a9dd37b1484c5787420af41c5acb97a2bfb20b639d92e2397117":[3,0,10,280,4],
-"namespacezypp.html#aff0a5458dd3d0a9dd37b1484c5787420af878adcf7113ab72a35fea4d49abdc50":[3,0,10,280,2],
-"namespacezypp.html#aff0a5458dd3d0a9dd37b1484c5787420afb54776d9ab348ca9eeb02a5b53d5ae3":[3,0,10,280,0],
-"namespacezypp.html#aff892f6ff32fdcbed249cb109da9f2b6":[3,0,10,394],
-"namespacezypp.html#affe162fe15983ad33d3af6caf2742634":[3,0,10,555],
-"namespacezypp.html#afff4c4330ddf197b8d032011bc45d71f":[3,0,10,308],
-"namespacezypp_1_1HACK.html":[3,0,10,15],
-"namespacezypp_1_1RepoManagerFlags.html":[3,0,10,33],
-"namespacezypp_1_1RepoManagerFlags.html#a00a4259ecb12d9ffde096d96dd364206":[3,0,10,33,5],
-"namespacezypp_1_1RepoManagerFlags.html#a14a84d89b639cfb9bfe538dbdb0a8efe":[3,0,10,33,4],
-"namespacezypp_1_1RepoManagerFlags.html#a14a84d89b639cfb9bfe538dbdb0a8efea593b25fb8967e7afa627e1c8cdf67c39":[3,0,10,33,4,0],
-"namespacezypp_1_1RepoManagerFlags.html#a14a84d89b639cfb9bfe538dbdb0a8efeab5f33a3054a4290aca2a48a07d26c04c":[3,0,10,33,4,1],
-"namespacezypp_1_1RepoManagerFlags.html#a14a84d89b639cfb9bfe538dbdb0a8efeac846b9439a3dc77fb68c34b6f5ee8c34":[3,0,10,33,4,2],
-"namespacezypp_1_1RepoManagerFlags.html#a52a68f79c0c389602aed250818ca6a7c":[3,0,10,33,0],
-"namespacezypp_1_1RepoManagerFlags.html#a856b4546cd3b3e8c5b095bec14ffd4d7":[3,0,10,33,2],
-"namespacezypp_1_1RepoManagerFlags.html#a856b4546cd3b3e8c5b095bec14ffd4d7a83c15107befd639f72dc5ec224bc1ff6":[3,0,10,33,2,0],
-"namespacezypp_1_1RepoManagerFlags.html#a856b4546cd3b3e8c5b095bec14ffd4d7ae3bf59124ecd58851e47b2a8e6fb6c49":[3,0,10,33,2,1],
-"namespacezypp_1_1RepoManagerFlags.html#aa6427c71bd93b4aa323263bc295581b2":[3,0,10,33,1],
-"namespacezypp_1_1RepoManagerFlags.html#aa6427c71bd93b4aa323263bc295581b2a54c77a5abe6106f690a49bdbdac09e96":[3,0,10,33,1,2],
-"namespacezypp_1_1RepoManagerFlags.html#aa6427c71bd93b4aa323263bc295581b2a5959c4b80cdb322b1f42517c3489b025":[3,0,10,33,1,1],
-"namespacezypp_1_1RepoManagerFlags.html#aa6427c71bd93b4aa323263bc295581b2ad9bce905d75ae46f80e1e511a7fafaed":[3,0,10,33,1,0],
-"namespacezypp_1_1RepoManagerFlags.html#ae0bf2b772c1e6ae19eeb88071a2925e4":[3,0,10,33,3],
-"namespacezypp_1_1RepoManagerFlags.html#ae0bf2b772c1e6ae19eeb88071a2925e4aa3e412522f4d7d11ebde2b8d4d38ed7b":[3,0,10,33,3,0],
-"namespacezypp_1_1RepoManagerFlags.html#ae0bf2b772c1e6ae19eeb88071a2925e4ad46a7cc7ccf850caa0e43254b3def7fd":[3,0,10,33,3,1],
-"namespacezypp_1_1__logtoolsdetail.html":[3,0,10,0],
-"namespacezypp_1_1applydeltarpm.html":[3,0,10,1],
-"namespacezypp_1_1applydeltarpm.html#a017723bb259a1b3f2115101ab6d9dcc2":[3,0,10,1,1],
-"namespacezypp_1_1applydeltarpm.html#a032107db5113d7bc784c28cbe6e53f80":[3,0,10,1,5],
-"namespacezypp_1_1applydeltarpm.html#a26703a6b4da2ce8a2d9834f9b41ccb39":[3,0,10,1,0],
-"namespacezypp_1_1applydeltarpm.html#a2cbf67511e289b24b9b7da4470435a33":[3,0,10,1,7],
-"namespacezypp_1_1applydeltarpm.html#a75c44b215b2f9cc3b9b1446619d908e9":[3,0,10,1,4],
-"namespacezypp_1_1applydeltarpm.html#a8ff0532a2b38095263ea6a15d00913c3":[3,0,10,1,6],
-"namespacezypp_1_1applydeltarpm.html#aae319c2d3f12ea63c03cde39003cee06":[3,0,10,1,2],
-"namespacezypp_1_1applydeltarpm.html#ad01485f67fbc0949b2d4fe49b3b7ec61":[3,0,10,1,3],
-"namespacezypp_1_1base.html":[3,0,10,2],
-"namespacezypp_1_1base.html#a0218c36e652aa1948d8a43aa3f68736d":[3,0,10,2,19],
-"namespacezypp_1_1base.html#a158373c7f3a80c99360aea391c68229f":[3,0,10,2,21],
-"namespacezypp_1_1base.html#a24b0882e23829160798494569410f8df":[3,0,10,2,17],
-"namespacezypp_1_1base.html#a54fb9661def1e8ebfba39a110a93c2a0":[3,0,10,2,15],
-"namespacezypp_1_1base.html#a975be5c3afb0c831a1451e819ca9787b":[3,0,10,2,16],
-"namespacezypp_1_1base.html#ab051dd95fba5221a2140778c3f9ed8d5":[3,0,10,2,20]
+"namespacezypp.html#afa53946d82e433de1744649a0b6d30f1":[3,0,10,450]
 };
